import { getToken } from '@/utils/Token';
import { getAPIUrl } from '../common';
import axios from 'axios';

export default class PracticeServices {
    static async createPractice(data) {

        const token = getToken('token')
        const option = {
            method: "POST",
            headers: {
                Authorization: `Bearer ${token}`,
            },
            url: `${getAPIUrl}Practice/add`,
            withCredentials: true,
            timeout: 1000 * 60 * 60,
            data: data
        };
        return axios(option);
    }

    static async getAllPractice(SubjectId, ChapterId, difficultiesId) {
        const token = getToken('token');
        const apiUrl = `${getAPIUrl}Practice/get`;

        // Construct URL with optional query parameters
        const queryParams = new URLSearchParams();
        if (SubjectId) queryParams.append('SubjectId', SubjectId);
        if (ChapterId) queryParams.append('ChapterId', ChapterId);
        if (difficultiesId) queryParams.append('DifficultyLevel', difficultiesId);
        const finalUrl = `${apiUrl}?${queryParams.toString()}`;

        const options = {
            method: "GET",
            headers: {
                Authorization: `Bearer ${token}`,
            },
            url: finalUrl,
            withCredentials: true,
            timeout: 1000 * 60 * 60,
        };

        return axios(options);
    }
    static async getAddedQuestion(PracticeId) {
        const token = getToken('token');
        const options = {
            method: "GET",
            headers: {
                Authorization: `Bearer ${token}`,
            },
            url: `${getAPIUrl}Practice/getAddedQestion/${PracticeId}`,
            withCredentials: true,
            timeout: 1000 * 60 * 60,
        };

        return axios(options);
    }


    static async getSingalPractice(PracticeId) {
        const token = getToken('token')
        const option = {
            method: "GET",
            headers: {
                Authorization: `Bearer ${token}`,
            },
            url: `${getAPIUrl}Practice/PracticeSingal/${PracticeId}`,
            withCredentials: true,
            timeout: 1000 * 60 * 60,
        };
        return axios(option);
    }
    static async getPracticeQestion(PracticeId) {
        const token = getToken('token')
        const option = {
            method: "GET",
            headers: {
                Authorization: `Bearer ${token}`,
            },
            url: `${getAPIUrl}Practice/getPracticeQestion/${PracticeId}`,
            withCredentials: true,
            timeout: 1000 * 60 * 60,
        };
        return axios(option);
    }


    static async getAllPracticeforuser( ChapterId) {
        const token = getToken('token');
        const apiUrl = `${getAPIUrl}Practice/getAllPracticeforuser`;
        const queryParams = new URLSearchParams();
        if (ChapterId) queryParams.append('ChapterId', ChapterId);
        const finalUrl = `${apiUrl}?${queryParams.toString()}`;
        const options = {
            method: "GET",
            headers: {
                Authorization: `Bearer ${token}`,
            },
            url: finalUrl,
            withCredentials: true,
            timeout: 1000 * 60 * 60,
        };

        return axios(options);
    }

    static async PracticeQuestions(PracticeId) {
        const token = getToken('token')
        const option = {
            method: "GET",
            headers: {
                Authorization: `Bearer ${token}`,
            },
            url: `${getAPIUrl}Practice/PracticeQuestions/${PracticeId}`,
            withCredentials: true,
            timeout: 1000 * 60 * 60,
        };
        return axios(option);
    }

    static async addQuestionsManual(data) {
        const token = getToken('token')
        const option = {
            method: "POST",
            headers: {
                Authorization: `Bearer ${token}`,
            },
            url: `${getAPIUrl}Practice/addQuestionsManual`,
            withCredentials: true,
            timeout: 1000 * 60 * 60,
            data: data
        };
        return axios(option);
    }


    static async addQuestionsAuto(PracticeId) {
        const token = getToken('token')
        const option = {
            method: "POST",
            headers: {
                Authorization: `Bearer ${token}`,
            },
            url: `${getAPIUrl}Practice/addQuestionsAuto/${PracticeId}`,
            withCredentials: true,
            timeout: 1000 * 60 * 60,
        };
        return axios(option);
    }
    static async createAnsSheet(data) {
        const token = getToken('token')
        const option = {
            method: "POST",
            headers: {
                Authorization: `Bearer ${token}`,
            },
            url: `${getAPIUrl}Practice/createAnsSheet`,
            withCredentials: true,
            data:data,
            timeout: 1000 * 60 * 60,
        };
        return axios(option);
    }
    static async getPracticeSheet(PracticeId) {
        const token = getToken('token')
        const option = {
            method: "GET",
            headers: {
                Authorization: `Bearer ${token}`,
            },
            url: `${getAPIUrl}Practice/getPracticeSheet/${PracticeId}`,
            withCredentials: true,
            timeout: 1000 * 60 * 60,
        };
        return axios(option);
    }
    static async PracticeResultsList(PracticeId) {
        const token = getToken('token')
        const option = {
            method: "GET",
            headers: {
                Authorization: `Bearer ${token}`,
            },
            url: `${getAPIUrl}Practice/PracticeResultsList/${PracticeId}`,
            withCredentials: true,
            timeout: 1000 * 60 * 60,
        };
        return axios(option);
    }

    static async PracticeResults(PracticeId,PracticeSheetId) {
        const token = getToken('token')
        const option = {
            method: "GET",
            headers: {
                Authorization: `Bearer ${token}`,
            },
            url: `${getAPIUrl}Practice/PracticeResults?PracticeId=${PracticeId}&PracticeSheetId=${PracticeSheetId}`,
            withCredentials: true,
            timeout: 1000 * 60 * 60,
        };
        return axios(option);
    }

    static async FinalSubmitPractice(PracticeId) {
        const token = getToken('token')
        const option = {
            method: "POST",
            headers: {
                Authorization: `Bearer ${token}`,
            },
            url: `${getAPIUrl}Practice/FinalSubmitPracticeSheet/${PracticeId}`,
            withCredentials: true,
            timeout: 1000 * 60 * 60,
        };
        return axios(option);
    }

    static async UpdatePractice(data) {
        const token = getToken('token')
        const option = {
            method: "PUT",
            headers: {
                Authorization: `Bearer ${token}`,
            },
            url: `${getAPIUrl}Practice/update`,
            withCredentials: true,
            timeout: 1000 * 60 * 60,
            data: data
        };
        return axios(option);
    }

}