"use client"
import CalenderServices from '@/Services/CalenderServices'
import React, { useEffect, useState } from 'react'
import { DemoItem } from '@mui/x-date-pickers/internals/demo';
import { DatePicker } from '@mui/x-date-pickers/DatePicker';
import { AdapterDayjs } from '@mui/x-date-pickers/AdapterDayjs';
import { LocalizationProvider } from '@mui/x-date-pickers/LocalizationProvider';
import dayjs from "dayjs";
import { Button, IconButton } from '@mui/material';
import "../../calenderentry/calenderentry.css"
import { MdDelete } from "react-icons/md";
import { FaEdit } from "react-icons/fa";
import { toast } from 'react-toastify';
import { useRouter } from 'next/navigation';
import Link from 'next/link';
import Dialog from '@mui/material/Dialog';
import DialogContent from '@mui/material/DialogContent';
import "../../subjectentry/subjectentry.css"
import InputLabel from '@mui/material/InputLabel';
import MenuItem from '@mui/material/MenuItem';
import FormControl from '@mui/material/FormControl';
import Select from '@mui/material/Select';
import FeedEntryServices from '@/Services/FeedEntryServices';

const today = dayjs();
const onemonthbefore = dayjs().subtract(1, 'months');

const FeedEntryList = () => {
    const router = useRouter()
    const [selectedDate1, setSelectedDate1] = useState(dayjs().subtract(1, 'months').format('YYYY-MM-DD'));
    const [selectedDate2, setSelectedDate2] = useState(dayjs().format('YYYY-MM-DD'));
    const [category, setcategory] = useState("update")
    const [calenderList, setCalenderList] = useState([])
    const [error, seterror] = useState("")
    const [refresh, setrefresh] = useState(false)
    const [open, setOpen] = React.useState(false);
    const [DeleteId, setDeleteId] = useState("")

    const handleClose = () => {
        setOpen(false);
        setDeleteId("")
    };

    useEffect(() => {
        const data = {
            startdate: `${selectedDate1} 00:00:00.0000000 +00:00`,
            enddate: `${selectedDate2} 00:00:00.0000000 +00:00`,
            Category: category
        }
        FeedEntryServices.getFeedEntry(data).then(({ data }) => {
            setCalenderList(data?.data)
            seterror("")
        }).catch((err) => {
            seterror(err?.response?.data?.error)
        })
    }, [selectedDate1, selectedDate2, refresh, category])

    const handleDateChange1 = (date) => {
        setSelectedDate1(date?.format('YYYY-MM-DD'));
    };
    const handleDateChange2 = (date) => {
        setSelectedDate2(date?.format('YYYY-MM-DD'));
    };

    const deleteHandeler = () => {
        FeedEntryServices.deleteFeedEntry(DeleteId).then(({ data }) => {
            toast.success(data?.message)
            setrefresh(!refresh)
            setOpen(false)
            setDeleteId("")
        }).catch((err) => {
            console.log(err?.response?.data);
        })
    }

    return (
        <div>
            <div className="titleHeading d-flex justify-content-between">
                <span>Feed Entry List</span>
                <Button variant="contained" className="submit_button px-4" size="small" onClick={() => router?.push(`/admin/feedentry`)}> add new entry</Button>
            </div>
            <div className='row m-0 listCalenderDate'>
                <div className='col-md-4'>
                    <LocalizationProvider dateAdapter={AdapterDayjs}>
                        <DemoItem label="Start Date (mm/dd/yyy)">
                            <DatePicker
                                defaultValue={onemonthbefore}
                                views={['year', 'month', 'day']}
                                onChange={handleDateChange1}
                            />
                        </DemoItem>
                    </LocalizationProvider>
                </div>
                <div className='col-md-4'>
                    <LocalizationProvider dateAdapter={AdapterDayjs}>
                        <DemoItem label="End Date (mm/dd/yyy)">
                            <DatePicker
                                defaultValue={today}
                                views={['year', 'month', 'day']}
                                onChange={handleDateChange2}
                            />
                        </DemoItem>
                    </LocalizationProvider>
                </div>
                <div className='col-md-4'>
                    category
                    <FormControl fullWidth>
                        <InputLabel id="demo-select-small-label">Category</InputLabel>
                        <Select
                            labelId="demo-select-small-label"
                            id="demo-select-small"
                            value={category}
                            label="Category"
                            onChange={(e) => setcategory(e?.target?.value)}
                        >
                            <MenuItem value="update">Update</MenuItem>
                            <MenuItem value="publication">Publication</MenuItem>
                        </Select>
                    </FormControl>
                </div>
            </div>

            {calenderList?.length > 0 && error == '' ?
                <div className='listCalenderDatediv3 brderTopDiv'>
                    <table className='w-100 border'>
                        <thead className='theadcalenderlist'>
                            <th className='calList1'>Sr.no</th>
                            <th className='calList2'>Date</th>
                            <th className='calList3'>Title Hindi</th>
                            <th className='calList3'>Title English</th>
                            <th className='calList4'>Action</th>
                        </thead>
                        <tbody>
                            {calenderList?.map((ele, i) => {
                                return (

                                    <tr key={i} className='tbodycalenderlist'>
                                        <td className='calList1'>{i + 1}</td>
                                        <td className='calList2'>{ele?.FeedEntryDate?.split("T")[0]}</td>
                                        <td className='calList3'>{ele?.Title_H}</td>
                                        <td className='calList3'>{ele?.Title_E}</td>
                                        <td className='calList4 p-0 m-0'>
                                            <Link href={{
                                                pathname: `/admin/feedentry`,
                                                query: {
                                                    Id: ele?.FeedId,
                                                    // Title: ele.Title,
                                                    // Texts: ele.Texts,
                                                    // EventDate: ele.FeedEntryDate,
                                                    // Remark: ele.Remark
                                                },
                                            }}
                                            // as={`/admin/calenderentry`}
                                            >
                                                <IconButton className='my-0 ' title='Edit'>
                                                    <FaEdit color='green' fontSize={20} />
                                                </IconButton>
                                            </Link>
                                            <IconButton className='my-0 ' title='Delete'
                                                onClick={() => {
                                                    setOpen(true)
                                                    setDeleteId(ele?.FeedId)
                                                }}>
                                                <MdDelete color='red' fontSize={20} />
                                            </IconButton>
                                        </td>
                                    </tr>

                                )
                            })}
                        </tbody>
                    </table>
                </div> :
                <div className='listCalenderDatediv2'>
                    {error}
                </div>}

            <Dialog
                open={open}
                // onClose={handleClose}
                aria-labelledby="alert-dialog-title"
                aria-describedby="alert-dialog-description"
            >

                <DialogContent className='dialog_container'>
                    <h5 className='mx-5 my-3 text-danger fw-bold'>Are you sure to Delete</h5>
                    <div className='d-flex justify-content-center'>
                        <Button onClick={handleClose} variant='contained' className='cancel_button mx-3' size='small'>No</Button>
                        <Button onClick={deleteHandeler} variant='contained' className='submit_button' size='small'>Yes</Button>
                    </div>
                </DialogContent>

            </Dialog>
        </div>
    )
}

export default FeedEntryList