"use client"
import React, { useEffect, useState } from 'react'
import "../../questionPreview/questionReview.css"
import "../../../subjectwise/subjectwise.css"
import { toast } from 'react-toastify';

import Format001 from '@/component/questionFormat/Format001';
import Pagination from '@mui/material/Pagination';
import Stack from '@mui/material/Stack';
import MiniLoader from '@/component/common/MiniLoader';
import PracticeServices from "@/Services/PracticeServices";
import { useSearchParams } from 'next/navigation';
import { Button } from '@mui/material';
import { useRouter } from 'next/navigation';

const Page = () => {
    const params = useSearchParams();
    const PracticeId = params.get("id");
    const [Question, setQuestion] = useState([])
    const [loader, setloader] = useState(false)
    const [currentPage, setCurrentPage] = useState(1);
    const questionsPerPage = 10;
    const router = useRouter()

    useEffect(() => {
        if (PracticeId) {
            setloader(true)
            PracticeServices.getAddedQuestion(PracticeId).then(({ data }) => {
                console.log(data)
                setQuestion(data?.Questions);
                setloader(false)
                // toast.success(data?.message)
            }).catch((err) =>
                toast.error(err?.response?.data?.message)
            )
        }
    }, [PracticeId])


    const handlePageChange = (event, value) => {
        setCurrentPage(value);
    };

    const indexOfLastQuestion = currentPage * questionsPerPage;
    const indexOfFirstQuestion = indexOfLastQuestion - questionsPerPage;
    const currentQuestions = Question.slice(indexOfFirstQuestion, indexOfLastQuestion);
    return (
        <>
            <div className='container'>
                <div className="titleHeading d-flex justify-content-between">
                    <span>Practice Questions Preview</span>
                    <Button variant="contained" className="submit_button px-4" size="small" onClick={() => router.push("/admin/practice/practicelist")}>Go Back</Button>
                </div>
            </div>
            {loader &&
                <div className='loading_wrapper'>
                    <MiniLoader />
                </div>}
            <div className='question_wrappper_Quiz'>
                <div className='row m-0'>
                    {currentQuestions?.length > 0 && currentQuestions?.map((ele, i) => {
                        return (
                            <div className={` col-md-12 p-1 p-md-2 m-0`} key={i}>
                                <Format001
                                    quesNo={indexOfFirstQuestion + i + 1}
                                    question={ele}
                                    HindiAnswer={ele?.HindiAnswer}
                                    EnglishAnswer={ele?.EnglishAnswer}
                                    isRead={true}
                                />
                            </div>
                        )
                    })}
                </div>
            </div>
            <div className='pagination_wrapper'>
                {Question?.length > 10 && Question?.length != 0 &&
                    <Stack spacing={2}>
                        <Pagination
                            count={Math.ceil(Question.length / questionsPerPage)}
                            page={currentPage}
                            className='color_btn'
                            onChange={handlePageChange}
                            size="large"
                        />
                    </Stack>
                }
            </div>
        </>
    )
}

export default Page