"use client"
import React, { useEffect, useState } from 'react'
import { FormControl, IconButton, InputLabel } from '@mui/material'
import MenuItem from '@mui/material/MenuItem';
import "./questionReview.css"
import Select from '@mui/material/Select';
import "../../../app/subjectwise/subjectwise.css"
import SubjectTreeServices from '@/Services/SubjectTreeServices';
import { toast } from 'react-toastify';
import CommonServices from '@/Services/CommonServices';
import QuestionReviewServices from '@/Services/QuestionReview';
import Format001 from '@/component/questionFormat/Format001';
import Pagination from '@mui/material/Pagination';
import Stack from '@mui/material/Stack';
import MiniLoader from '@/component/common/MiniLoader';
import { FaRegEdit } from "react-icons/fa";
import Link from 'next/link';
const Page = () => {

    const [SubjectList, setSubjectList] = useState([])
    const [ChaptertList, setChaptertList] = useState([])
    const [PartList, setPartList] = useState([])
    const [Question, setQuestion] = useState([])
    const [loader, setloader] = useState(false)
    const [SubjectId, setSubjectId] = useState("")
    const [ChapterId, setChapterId] = useState("")
    const [PartId, setPartId] = useState("")
    const [currentPage, setCurrentPage] = useState(1);
    const questionsPerPage = 10;

    useEffect(() => {
        SubjectTreeServices.getOneLeveTreeDataforadmin(0).then(({ data }) => {
            setSubjectList(data.tree);
            setPartList([])
            setChaptertList([])
        }).catch((e) => {
            console.log(e)
        })
    }, [])
    useEffect(() => {
        if (SubjectId) {
            SubjectTreeServices.getOneLeveTreeDataforadmin(SubjectId).then(({ data }) => {
                setPartList(data.tree);
                setChaptertList([])
            }).catch((e) => {
                console.log(e)
            })
        }
    }, [SubjectId])
    useEffect(() => {
        if (PartId) {
            SubjectTreeServices.getOneLeveTreeDataforadmin(PartId).then(({ data }) => {
                setChaptertList(data.tree);
            }).catch((e) => {
                console.log(e)
            })
        }
    }, [PartId])
    useEffect(() => {
        // if (SubjectId || ChapterId || PartId) {
        //     setloader(true)
        // }
        if (SubjectId) {
            setloader(true)
            QuestionReviewServices.QuestionReview(SubjectId, PartId, ChapterId).then(({ data }) => {
                setQuestion(data?.questions);
                setloader(false)
                toast.success(data?.message)
            }).catch((err) =>
                toast.error(err?.response?.data?.message)
            )
        }
    }, [SubjectId, ChapterId, PartId])

    const handlePageChange = (event, value) => {
        setCurrentPage(value);
    };


    const SubjectName = SubjectList?.find(node => node.NodeId === SubjectId);
    const PartName = PartList?.find(node => node.NodeId === PartId);
    const ChapterName = ChaptertList?.find(node => node.NodeId === ChapterId);


    const indexOfLastQuestion = currentPage * questionsPerPage;
    const indexOfFirstQuestion = indexOfLastQuestion - questionsPerPage;
    const currentQuestions = Question.slice(indexOfFirstQuestion, indexOfLastQuestion);
    return (
        <>
            <div className='container'>
                <div className="titleHeading d-flex justify-content-between">
                    <span>Question Review</span>
                </div>
                <div className='row'>
                    <div className='col-md-4 mb-3'>
                        <FormControl fullWidth size="small">
                            <InputLabel id="demo-select-small-label">Subject List</InputLabel>
                            <Select
                                labelId="demo-select-small-label"
                                value={SubjectId}
                                label="Subject List"
                                name="Subject List"
                                onChange={(e) => setSubjectId(e.target.value)}
                            >
                                <MenuItem value="">
                                    <em>None</em>
                                </MenuItem>
                                {SubjectList?.map((ele, i) => {
                                    return <MenuItem key={i} value={ele.NodeId}>{`${ele.NodeName_E} || ${ele.NodeName_H}`}</MenuItem>
                                })}
                            </Select>
                        </FormControl>
                    </div>
                    <div className='col-md-4 mb-3'>
                        <FormControl fullWidth size="small">
                            <InputLabel id="demo-select-small-label">Part List</InputLabel>
                            <Select
                                labelId="demo-select-small-label"
                                value={PartId}
                                label="Part List"
                                name='Part List'
                                onChange={(e) => setPartId(e.target.value)}
                            >
                                <MenuItem value="">
                                    <em>None</em>
                                </MenuItem>
                                {PartList?.map((ele, i) => {
                                    return <MenuItem key={i} value={ele.NodeId}>{`${ele.NodeName_E} || ${ele.NodeName_H}`}</MenuItem>
                                })}
                            </Select>
                        </FormControl>
                    </div>
                    <div className='col-md-4 mb-3'>
                        <FormControl fullWidth size="small">
                            <InputLabel id="demo-select-small-label">Chapter List</InputLabel>
                            <Select
                                labelId="demo-select-small-label"
                                value={ChapterId}
                                label="Chapter List"
                                name='Chapter List'
                                onChange={(e) => setChapterId(e.target.value)}
                            >
                                <MenuItem value="">
                                    <em>None</em>
                                </MenuItem>
                                {ChaptertList?.map((ele, i) => {
                                    return <MenuItem key={i} value={ele.NodeId}>{`${ele.NodeName_E} || ${ele.NodeName_H}`}</MenuItem>
                                })}
                            </Select>
                        </FormControl>
                    </div>
                </div>
            </div>
            {loader &&
                <div className='loading_wrapper'>
                    <MiniLoader />
                </div>}

            {(!SubjectId && !ChapterId && !PartId) && <div className='review_info_wrapper'>
                <p className='review_info'>Please Select Any field to load Question</p>
            </div>}

            <div className='question_wrappper container'>
                <div className='row m-0'>
                    {currentQuestions && currentQuestions?.map((ele, i) => {
                        return (
                            <div className={` col-md-12 p-1 p-md-2 m-0`} key={i} >
                                <hr />
                                {`${SubjectList?.find(node => node?.NodeId === ele?.SubjectId)?.NodeName_E} => ${PartList?.find(node => node?.NodeId === ele?.PartId)?.NodeName_E} => ${ChaptertList.length > 0 ? ChaptertList?.find(node => node?.NodeId == ele?.ChepterId)?.NodeName_E : ""}`}
                                &nbsp;
                                <Link
                                    key={i}
                                    style={{ textDecoration: "none" }}
                                    href={{
                                        pathname: `/admin/singleQuestionUpload`,
                                        query: {
                                            Id: ele?.QuestionId,
                                        },
                                    }}
                                >
                                    <FaRegEdit size={20} color='green' />
                                </Link>
                                <hr />
                                <div>
                                    <Format001
                                        quesNo={indexOfFirstQuestion + i + 1}
                                        question={ele}
                                        HindiAnswer={ele?.HindiAnswer}
                                        EnglishAnswer={ele?.EnglishAnswer}
                                        isRead={true}
                                    />
                                </div>
                            </div>
                        )
                    })}
                </div>
            </div>

            <div className='pagination_wrapper'>
                {Question?.length > 10 && Question?.length != 0 &&
                    <Stack spacing={2}>
                        <Pagination
                            count={Math.ceil(Question.length / questionsPerPage)}
                            page={currentPage}
                            className='color_btn'
                            onChange={handlePageChange}
                            size="large"
                        />
                    </Stack>
                }
            </div>
        </>
    )
}

export default Page