"use client"
import { Button, TextField } from '@mui/material'
import React, { useEffect, useState } from 'react'
import InputLabel from '@mui/material/InputLabel';
import MenuItem from '@mui/material/MenuItem';
import FormControl from '@mui/material/FormControl';
import Select from '@mui/material/Select';
import SubjectTreeServices from '@/Services/SubjectTreeServices';
import CommonServices from '@/Services/CommonServices';
import "../quizEntry/quizentry.css"
import QuestionUploadServices from '@/Services/QuestionUploadServices';
import { toast } from 'react-toastify';

const QuestionUpload = () => {
  const [SubjectList, setSubjectList] = useState([])
  const [ChaptertList, setChaptertList] = useState([])
  const [Part, setPart] = useState([])

  const [SubjectId, setSubjectId] = useState("")
  const [ChapterId, setChapterId] = useState("")
  const [PartId, setPartId] = useState("")
  const [Hint, setHint] = useState("")
  const [selectedFile, setselectedFile] = useState([])

  const [Loading, setLoading] = useState(false);
  const [error, setError] = useState('');

  // SubjectId, ChepterId, DifficultyLevel, Hints
  const handleFileChange = (event) => {
    const fileInput = event.target;
    const selectedFile = fileInput.files[0];

    if (!selectedFile) {
      setError('Please select a file.');
      return;
    }
    const allowedExtensions = /(\.xls|\.xlsx)$/i;
    if (!allowedExtensions.test(selectedFile.name)) {
      setError('Invalid file type. Please select an Excel file.');
      return;
    }
    setError('');
    setselectedFile(selectedFile)
  };

  useEffect(() => {
    SubjectTreeServices.getOneLeveTreeDataforadmin(0).then(({ data }) => {
      setSubjectList(data.tree);
    })
  }, [])

  useEffect(() => {
    if (SubjectId) {
      SubjectTreeServices.getOneLeveTreeDataforadmin(SubjectId).then(({ data }) => {
        setPart(data.tree);
      })
    }
  }, [SubjectId])
  useEffect(() => {
    if (PartId) {
      SubjectTreeServices.getOneLeveTreeDataforadmin(PartId).then(({ data }) => {
        setChaptertList(data.tree);
      })
    }
  }, [PartId])

  const reset = () => {
    setSubjectId("")
    setChapterId("")
    setDifficultiesId("")
    setHint("")
    setselectedFile([])
  }

  const uploadHandler = () => {
    setLoading(true)
    const data = new FormData();
    data.append('SubjectId', SubjectId);
    data.append('PartId', PartId);
    data.append('ChepterId', ChapterId);
    data.append('Hints', Hint);
    data.append('file', selectedFile);

    QuestionUploadServices.QuestionUpload(data).then(({ data }) => {
      toast.success(data.message)
      setLoading(false)
      reset()
    }).catch((err) => {
      toast.error(err?.response?.data?.error)
      setLoading(false)
    })
  }

  return (
    <div>
      <div className="titleHeading d-flex justify-content-between">
        <span>Excel Question Upload</span>
        {/* <Button variant="contained" className="submit_button px-4" size="small" onClick={() => router.push("/admin/quizEntry/list")}>list</Button> */}
      </div>

      <div className='Quiz_div p-2 p-md-4' style={{ minHeight: "75vh" }}>
        <div className='row m-0'>
          <div className='col-md-6'>
            <div className='row'>
              <div className='col-md-12 my-2'>
                <FormControl fullWidth size="small">
                  <InputLabel id="demo-select-small-label">Subject list*</InputLabel>
                  <Select
                    labelId="demo-select-small-label"
                    value={SubjectId}
                    label="Subject list*"
                    onChange={(e) => setSubjectId(e.target.value)}
                  >
                    <MenuItem value="">
                      <em>None</em>
                    </MenuItem>
                    {SubjectList?.map((ele, i) => {
                      return <MenuItem key={i} value={ele.NodeId}>{`${ele.NodeName_E} || ${ele.NodeName_H}`}</MenuItem>
                    })}
                  </Select>
                </FormControl>
              </div>
              <div className='col-md-12 my-2'>
                <FormControl fullWidth size="small">
                  <InputLabel id="demo-select-small-label">Part List*</InputLabel>
                  <Select
                    labelId="demo-select-small-label"
                    value={PartId}
                    label="Part List*"
                    name='Part List*'
                    onChange={(e) => setPartId(e.target.value)}
                  >
                    <MenuItem value="">
                      <em>None</em>
                    </MenuItem>
                    {Part?.map((ele, i) => {
                      return <MenuItem key={i} value={ele.NodeId}>{`${ele.NodeName_E} || ${ele.NodeName_H}`}</MenuItem>
                    })}
                  </Select>
                </FormControl>
              </div>

              <div className='col-md-12 my-2'>
                <FormControl fullWidth size="small">
                  <InputLabel id="demo-select-small-label">Chapter list*</InputLabel>
                  <Select
                    labelId="demo-select-small-label"
                    value={ChapterId}
                    label="Subject list*"
                    name="Subject list*"
                    onChange={(e) => setChapterId(e.target.value)}
                  >
                    <MenuItem value="">
                      <em>None</em>
                    </MenuItem>
                    {ChaptertList?.map((ele, i) => {
                      return <MenuItem key={i} value={ele.NodeId}>{`${ele.NodeName_E} || ${ele.NodeName_H}`}</MenuItem>
                    })}
                  </Select>
                </FormControl>
              </div>

              

              <div className='col-md-12 my-2'>
                <TextField fullWidth
                  size='small'
                  label="Hint(optional)"
                  variant="outlined"
                  value={Hint}
                  onChange={(e) => setHint(e.target.value)}
                  rows={4}
                  multiline
                />
              </div>
            </div>
          </div>

          <div className='col-md-6'>
            <div className='row m-0 my-2'>
              <div className="borderfortop rounded p-3">
                <h6 className="mb-4">Upload Excel</h6>
                <input
                  type="file"
                  id="fileInput"
                  accept=".xls, .xlsx"
                  onChange={handleFileChange}
                />
                {error && <p className='my-2 text-danger fw-bold'>{error}</p>}
              </div>
            </div>

            <div className='text-center my-4'>
              <Button
                className='submit_button w-50 m-auto'
                variant='contained'
                disabled={Loading || error.length > 0}
                onClick={uploadHandler}
              >
                {Loading ? "uploading ....." : "upload"}
              </Button>
            </div>
          </div>

        </div>
      </div>
    </div>
  )
}



export default QuestionUpload