"use client"
import HomePageServices from "@/Services/HomePageServices";
import { Button, Dialog, DialogContent, TextField } from "@mui/material";
import React, { useEffect, useState } from "react";
import { toast } from "react-toastify";
import { IconButton } from '@mui/material';
import { MdDelete } from "react-icons/md";
import { FaEdit } from "react-icons/fa";
import VisibilityIcon from '@mui/icons-material/Visibility';
import VisibilityOffIcon from '@mui/icons-material/VisibilityOff';

const Page = () => {
    // SlokTitle, SlokTexts, Remark
    const [SlokTitle, setSlokTitle] = useState("")
    const [SlokTexts, setSlokTexts] = useState("")
    const [Remark, setRemark] = useState("")

    const [TableList, setTableList] = useState([])
    const [refresh, setrefresh] = useState(false)
    const [open, setOpen] = useState(false);
    const [Toggle, setToggle] = useState(false)

    const [Id, setId] = useState("")
    const [EditId, setEditId] = useState("")
    const [EditItems, setEditItems] = useState({})
    // Title,Texts,Remark
    const reset = () => {
        setSlokTitle("")
        setSlokTexts("")
        setRemark("")
    }

    const handleClose = () => {
        setOpen(false);
        setId("")
    };
    const submitHandeler = () => {
        HomePageServices.addSloksEntry({ SlokTitle, SlokTexts, Remark }).then(({ data }) => {
            toast.success(data.message)
            reset()
            setrefresh(!refresh)
            setToggle(false)
        }).catch((err) => {
            toast.error(err.response.data.error)
        })
    }

    const deleteHandeler = () => {
        HomePageServices.deleteSloks(Id).then(({ data }) => {
            toast.success(data?.message)
            setOpen(false)
            setrefresh(!refresh)
        }).catch((err) => {
            setOpen(false)
            toast.error(err.response.data.error)
        })
    }

    const editHandle = (ele) => {
        setEditId(ele.SlokId)
        setToggle(true)
        setEditItems(ele)
        setSlokTitle(ele.SlokTitle)
        setSlokTexts(ele.SlokTexts)
        setRemark(ele.Remark)
    }

    const updateHandeler = () => {
        HomePageServices.editSloks({ SlokId: EditId, SlokTitle, SlokTexts, Remark }).then(({ data }) => {
            setrefresh(!refresh)
            setToggle(false)
            reset()
            toast.success(data.message)
        }).catch((err) => {
            toast.error(err.response.data.error)
        })
    }

    const toggleStatus = (id) => {
        HomePageServices.statusUpdateSloks(id).then(({ data }) => {
            setrefresh(!refresh)
            toast.success(data.message)
        }).catch((err) => {
            console.log(err.response.data.error);
        })
    }


    useEffect(() => {
        HomePageServices.getSloks().then(({ data }) => {
            setTableList(data?.data);
            toast.success(data.data.message)
        }).catch((err) => {
            toast.error(err.response.data.err)
        })
    }, [refresh])

    return (
        <>
            <div className="titleHeading d-flex justify-content-between">
                <span>Sloks Entry</span>
                <Button variant="contained" className="submit_button px-4" size="small" onClick={() => {
                    setToggle(!Toggle)
                    setEditId("")
                }}>Add Sloks</Button>
            </div>
            {Toggle && <div className="brderTopDiv p-3">
                <div className="row">
                    <div className="col-md-8">
                        <div className="col-md-12 mb-3">
                            <TextField
                                id="outlined-multiline-static"
                                label="Title"
                                fullWidth
                                onChange={(e) => setSlokTitle(e.target.value)}
                                value={SlokTitle}
                                size="small"
                                color="success"
                            />
                        </div>
                        <div className="col-md-12 mb-3">
                            <TextField
                                id="outlined-multiline-static"
                                label="Sloks"
                                fullWidth
                                onChange={(e) => setSlokTexts(e.target.value)}
                                value={SlokTexts}
                                size="small"
                                color="success"
                                multiline
                                rows={3}
                            />
                        </div>
                    </div>
                    <div className="col-md-4">
                        <div className="col-md-12 mb-3">
                            <TextField
                                id="outlined-multiline-static"
                                label="Remarks"
                                fullWidth
                                onChange={(e) => setRemark(e.target.value)}
                                value={Remark}
                                size="small"
                                color="success"
                            />
                        </div>
                        <div className="col-md-12 mb-3">
                            {!EditId && <Button variant="contained" className="submit_button" fullWidth size="small" onClick={submitHandeler}>Submit</Button>}
                            {!!EditId && <Button variant="contained" className="submit_button" fullWidth size="small" onClick={updateHandeler}>update</Button>}
                        </div>
                    </div>
                </div>

            </div>}

            <div className=' brderTopDiv mt-3'>
                <table className='w-100 border'>
                    <thead className='theadcalenderlist'>
                        <tr>
                            <th style={{ width: "10%" }}>Sr. No</th>
                            <th style={{ width: "32%" }}>SlokTitle</th>
                            <th style={{ width: "40%" }}>Sloks</th>
                            <th style={{ width: "8%", textAlign: "center" }}>Status</th>
                            <th style={{ width: "10%", textAlign: "center" }}>Actions</th>
                        </tr>
                    </thead>
                    <tbody>
                        {TableList.map((ele, i) => {
                            return <tr key={i}>
                                <td className="px-3 m-0" style={{ width: "10%" }}>{i + 1}</td>
                                <td className="p-0 m-0" style={{ width: "32%" }}>{ele.SlokTitle}</td>
                                <td className="p-0 m-0" style={{ width: "40%" }}>{ele.SlokTexts}</td>
                                <td className="p-0 m-0" style={{ width: "8%", textAlign: "center" }}>
                                    {!!ele.Active ?
                                        <VisibilityIcon fontSize="small" sx={{ color: "green" }} onClick={() => toggleStatus(ele.SlokId)} />
                                        : <VisibilityOffIcon fontSize="small" sx={{ color: "red" }} onClick={() => toggleStatus(ele.SlokId)} />
                                    }</td>
                                <td className="p-0 m-0" style={{ width: "10%", textAlign: "center" }}>
                                    <div className="d-flex">
                                        <IconButton className='my-0 ' title='Edit' onClick={() => editHandle(ele)}>
                                            <FaEdit color='green' fontSize={20} />
                                        </IconButton>
                                        <IconButton className='my-0 ' title='Delete'
                                            onClick={() => {
                                                setId(ele.SlokId)
                                                setOpen(true)
                                            }} >
                                            <MdDelete color='red' fontSize={20} />
                                        </IconButton>
                                    </div>
                                </td>
                            </tr>
                        })}
                    </tbody>
                </table>
            </div>

            <Dialog
                open={open}
                // onClose={handleClose}
                aria-labelledby="alert-dialog-title"
                aria-describedby="alert-dialog-description"
            >

                <DialogContent className='dialog_container'>
                    <h5 className='mx-5 my-3 text-danger fw-bold'>Are you sure to delete</h5>
                    <div className='d-flex justify-content-center'>
                        <Button onClick={handleClose} variant='contained' className='cancel_button mx-3' size='small'>no</Button>
                        <Button onClick={deleteHandeler} variant='contained' className='submit_button' size='small'>yes</Button>
                    </div>
                </DialogContent>

            </Dialog>
        </>
    )
}

export default Page