"use client"
import React, { useState, useEffect } from 'react';
import 'bootstrap/dist/css/bootstrap.min.css';
import '../subscription/subscription.css';
import SubscriptionServices from '@/Services/SubscriptionServices';
import VisibilityIcon from '@mui/icons-material/Visibility';
import VisibilityOffIcon from '@mui/icons-material/VisibilityOff';
import DeleteIcon from '@mui/icons-material/Delete';
import EditNoteIcon from '@mui/icons-material/EditNote';
import "../calenderentry/calenderentry.css"
import { Button } from '@mui/material';
import { toast } from 'react-toastify';

const Subscription = () => {
    const [plans, setPlans] = useState([]);
    const [editingPlanId, setEditingPlanId] = useState(null);
    const [newPlan, setNewPlan] = useState({ Name: '', Amount: '' });
    const [showCreateInput, setShowCreateInput] = useState(false);
    const [EditId, setEditId] = useState(null)
    const [refresh, setrefresh] = useState(false)
    useEffect(() => {
        SubscriptionServices.getSubscription()
            .then(({ data }) => {
                setPlans(data.data);
            })
            .catch((err) => {
                console.log(err.response);
            });
    }, [EditId,refresh]);

    const handleStatusUpdate = (id) => {
        SubscriptionServices.statusUpdateVisible(id).then(({data})=>{
            toast.success ("Update Successfully")
            setrefresh(!refresh)
        })
    };

    const handleEdit = (plan) => {
        setEditId(plan.SubscriptionId)
        setShowCreateInput(!showCreateInput)
        setNewPlan({ Name: plan.Name, Amount: plan.Amount });

    };

    const saveChanges = () => {
        SubscriptionServices.updateSubscription(EditId, newPlan)
            .then(({ data }) => {
                setEditingPlanId(null);
                setShowCreateInput(!showCreateInput)
                setEditId(null)
                setNewPlan({
                    Name: '', Amount: '' 
                })
            })
            .catch((err) => {
                console.log(err.response);
            });
    };

    const handleCreate = () => {
        if (showCreateInput === false) {
            setShowCreateInput(true);
        } else {
            setShowCreateInput(false);
        }
    };

    const handleCreatePlan = () => {
        SubscriptionServices.addSubscription(newPlan)
            .then(({ data }) => {
                setPlans([...plans, data.data])
                plans.push(data.data);
            })
            .catch((err) => {
                console.log(err.response);
            });
        setNewPlan({ Name: '', Amount: '' });
        setShowCreateInput(false);
    };

    return (
        <div>
            <div className="titleHeading d-flex justify-content-between">
                <span>Subscription Plans</span>
                <Button variant='contained' className='submit_button' onClick={handleCreate}>Add plan</Button>
            </div>
            <div className='listCalenderDate'>
                {showCreateInput && (
                    <div className='w-75 mb-3'>
                        <input
                            type="text"
                            value={newPlan.Name}
                            onChange={(e) => setNewPlan({ ...newPlan, Name: e.target.value })}
                            placeholder="Name"
                            className='w-25 m-1'
                        />
                        <input
                            type="text"
                            value={newPlan.Amount}
                            onChange={(e) => setNewPlan({ ...newPlan, Amount: e.target.value })}
                            placeholder="Amount"
                            className='w-25 m-1'
                        />
                        {EditId === null ?
                            <Button variant='contained' className='submit_button w-25 m-1' onClick={handleCreatePlan}>Create</Button>
                            :
                            <Button variant='contained' className='submit_button w-25 m-1' onClick={saveChanges}>Update</Button>
                        }
                    </div>
                )}
                <table className='w-100 border'>
                    <thead>
                        <tr>
                            <th>Name</th>
                            <th>Amount</th>
                            <th>Status</th>
                            <th>Created At</th>
                            <th>Actions</th>
                        </tr>
                    </thead>
                    <tbody>
                        {plans.map((plan) => (
                            <tr key={plan.SubscriptionId}>
                                <td>{plan.Name}</td>
                                <td>{`₹${plan.Amount}`}</td>
                                <td>{plan.Status ? 'Active' : 'Inactive'}</td>
                                <td>{new Date(plan.createdAt).toLocaleDateString()}</td>
                                <td>
                                    <EditNoteIcon onClick={() => handleEdit(plan)} />
                                    {!plan.Status ?
                                        <VisibilityOffIcon onClick={() => handleStatusUpdate(plan.SubscriptionId)} sx={{ fontSize: "20px", marginLeft: "5px", color: "red" }} />
                                        :
                                        <VisibilityIcon onClick={() => handleStatusUpdate(plan.SubscriptionId)} sx={{ fontSize: "20px", marginLeft: "5px", color: "green" }} />}
                                </td>
                            </tr>
                        ))}
                    </tbody>
                </table>
            </div>
        </div>
    );
};

export default Subscription;
