"use client";

import { Button, Paper, Dialog, DialogContent } from "@mui/material";
import React, { useEffect, useState, useRef } from "react";
import { useRouter } from "next/navigation";
import PracticeServices from "@/Services/PracticeServices";
import Format001 from "@/component/questionFormat/Format001";
import "@/app/practice/practice.css";
import { useSelector } from "react-redux";

const PracticePortal = ({ params }) => {
  const [Practicedata, setPractice] = useState({});
  const [PracticeQueList, setPracticeQueList] = useState([]);
  const [DisplayQue, setDisplayQue] = useState({});
  const [queIndex, setQueIndex] = useState(0);
  const [answerSheet, setAnswerSheet] = useState([]);
  const [Answer, setAnswer] = useState({});
  const [isLoading, setIsLoading] = useState(false);
  const [openModel, setOpneModel] = useState(false);
  const [disabled, setDisabled] = useState(false);
  const [PracticeLogs, setPracticeLogs] = useState();
  const router = useRouter();
  const language = useSelector((state) => state.language);
  const [localStorageLanguage, setlocalStorageLanguage] = useState(null);
  const containerRef = useRef(null);
  const [open, setOpen] = React.useState(false);

  const scrollLeft = () => {
    containerRef.current.scrollBy({ left: -50, behavior: "smooth" });
  };
  const scrollRight = () => {
    containerRef.current.scrollBy({ left: 50, behavior: "smooth" });
  };

  const handleClose = () => {
    setOpen(false);
  };

  useEffect(() => {
    const handleBeforeUnload = (event) => {
      event.preventDefault();
      router.replace(`/practice/practicelist?id=${Practicedata?.SubjectId}`);
    };

    window.addEventListener("popstate", handleBeforeUnload);

    return () => {
      window.removeEventListener("popstate", handleBeforeUnload);
    };
  }, [router, Practicedata?.SubjectId]);

  function finalSubmit() {
    PracticeServices.FinalSubmitPractice(params?.id)
      .then(({ data }) => {
        if (data.success) {
          PracticeServices?.PracticeResultsList(params?.id)
            .then(({ data }) => {
              setPracticeLogs(data?.PracticeSheets[0]);
              setOpneModel(true);
            })
            .catch((err) => {
              console.log(err.response);
            });
          setIsLoading(false);
        }
      })
      .catch((err) => {
        console.log(err);
        setIsLoading(true);
      });
  }
  // Create Answer Sheet Entry
  const answerSheetEntry = async (payload) => {
    setIsLoading(true);

    PracticeServices.createAnsSheet(payload)
      .then(({ data }) => {
        if (data.success) {
          setAnswerSheet((prev) => {
            // Check if the QuestionId already exists in the AnswerSheet
            const existingIndex = prev.findIndex(
              (item) => item.QuestionId === data?.PracticSheetAns.QuestionId
            );

            if (existingIndex !== -1) {
              // If it exists, replace the existing answer
              return prev.map((item, index) =>
                index === existingIndex ? data?.PracticSheetAns : item
              );
            } else {
              // If it doesn't exist, append the new answer
              return [...prev, data?.PracticSheetAns];
            }
          });

          // setAnswerSheet((prev) => [...prev, data?.PracticSheetAns]);
          setAnswer({});
        }
        setIsLoading(false);
      })
      .catch((err) => {
        console.log(err);
        setIsLoading(false);
      });
  };

  // Set language from localStorage
  useEffect(() => {
    const localStorageLanguage =
      typeof localStorage !== "undefined"
        ? localStorage.getItem("language")
        : null;
    setlocalStorageLanguage(localStorageLanguage);
  }, [language]);

  // Get Single Practice and Practice Question
  const initAPI = async () => {
    setIsLoading(true);
    try {
      const Practice = await PracticeServices?.getSingalPractice(params?.id);
      setPractice(Practice?.data?.data[0]);

      const practiceQuestion = await PracticeServices?.getPracticeQestion(
        params?.id
      );
      const questions = practiceQuestion?.data?.questions || [];

      const { data } = await PracticeServices?.getPracticeSheet(params?.id);
      const historyLength = data?.historyPracticeSheetAns?.length;
      if (questions.length > 0 && data?.historyPracticeSheetAns?.length > 0) {
        setPracticeQueList([]);
        setPracticeQueList(questions);
        setAnswerSheet(data?.historyPracticeSheetAns);
        const lastAnswer = data?.historyPracticeSheetAns[data?.historyPracticeSheetAns?.length - 1];
        const lastQuestionId = lastAnswer?.QuestionId;
        const lastQuestionIndex = questions.findIndex(q => q.QuestionId == lastQuestionId);
        if (lastQuestionIndex != -1) {
          setDisplayQue(questions[lastQuestionIndex]);
          setQueIndex(lastQuestionIndex);
        }}
       else {
        setPracticeQueList(questions);
        setDisplayQue(questions[0]);
      }
    } catch (err) {
      console.log(err);
    } finally {
      setIsLoading(false);
    }
  };
  //first time call api
  useEffect(() => {
    initAPI();
  }, [params]);

  useEffect(() => {
    const isAnswerd = answerSheet?.find(
      (val) => val?.QuestionId == PracticeQueList[queIndex]?.QuestionId
    );

    if (isAnswerd) {
      const obj = {
        HindiAnswer: isAnswerd?.HindiAnswer,
        EnglishAnswer: isAnswerd?.EnglishAnswer,
      };
      setAnswer(obj); //change it into object
    } else {
      setAnswer({});
    }
  }, [answerSheet]);

  const answerSubmit = (answer) => {
    setAnswer(answer);
    const payload = {
      PracticeId: params?.id,
      QuestionId: DisplayQue?.QuestionId,
      HindiAnswer: answer?.HindiAnswer,
      EnglishAnswer: answer?.EnglishAnswer,
      AnswerStatus: "answer",
      language: language?.language || localStorageLanguage,
    };
    answerSheetEntry(payload);
  };
  //this function working Tabmenu change the question
  const Tabmenu = (QuesInd) => {
    // scrollLeft();
    setQueIndex(QuesInd);
    setDisplayQue(PracticeQueList[QuesInd]);
    const isAnswerd = answerSheet?.find(
      (val) => val?.QuestionId == PracticeQueList[QuesInd]?.QuestionId
    );

    if (isAnswerd) {
      const obj = {
        HindiAnswer: isAnswerd?.HindiAnswer,
        EnglishAnswer: isAnswerd?.EnglishAnswer,
      };
      setAnswer(obj); //change it into object
    } else {
      setAnswer({});
    }
  };

  // Submit and next question function
  const Submit = () => {
    scrollRight();
    setQueIndex((prevIndex) => prevIndex + 1);
    setDisplayQue(PracticeQueList[queIndex + 1]);
    const isAnswerd = answerSheet?.find(
      (val) => val?.QuestionId == PracticeQueList[queIndex + 1]?.QuestionId
    );

    if (isAnswerd) {
      const obj = {
        HindiAnswer: isAnswerd?.HindiAnswer,
        EnglishAnswer: isAnswerd?.EnglishAnswer,
      };
      setAnswer(obj); //change it into object
    } else {
      setAnswer({});
    }
  };

  // Previous question
  const Previous = () => {
    scrollLeft();
    setQueIndex((prevIndex) => prevIndex - 1);
    setDisplayQue(PracticeQueList[queIndex - 1]);
    const isAnswerd = answerSheet?.find(
      (val) => val?.QuestionId == PracticeQueList[queIndex - 1]?.QuestionId
    );

    if (isAnswerd) {
      const obj = {
        HindiAnswer: isAnswerd?.HindiAnswer,
        EnglishAnswer: isAnswerd?.EnglishAnswer,
      };
      setAnswer(obj); //change it into object
    } else {
      setAnswer({});
    }
  };
  return (
    <div className=" bg-light w-100">
      <div className="container text-align minheight100vh">
        <div className="row">
          <Paper className="quizheadeing p-1 my-1" elevation={2}>
            <div className="row">
              <div className="col-md-4 col-12  practic_back_bottun ">
                <Button
                  variant="contained"
                  color="success"
                  onClick={() =>
                    router.push(
                      `/practice/practicelist?id=${Practicedata?.SubjectId}`
                    )
                  }
                  size="small"
                  className="m-0 py-1 px-3 practiceButton capitalised"
                >
                  {(!language.loading && language?.language == "ENGLISH") ||
                    localStorageLanguage == "ENGLISH"
                    ? "Back to previous page"
                    : "पिछले पृष्ठ पर वापस जाए"}
                </Button>
              </div>
              <div className="col-md-4 col-12 mt-1 px-1 practice_head2">
              {(!language.loading && language?.language == "ENGLISH") ||
                  localStorageLanguage == "ENGLISH" ? (
                  <h6 className="m-1 m-0 p-0  fw-bold portalHeading">
                    Number of Questions: {Practicedata?.TotalQusetion}
                  </h6>
                ) : (
                  <h6 className="m-1  fw-bold portalHeading">
                    प्रश्नों की संख्या: {Practicedata?.TotalQusetion}
                  </h6>
                )}
              </div>
              <div className="col-md-4 col-12  practice_head">
              <div className="fw-bold portalHeading text-success ">
                  {(!language.loading && language?.language == "ENGLISH") ||
                    localStorageLanguage == "ENGLISH"
                    ? `Number of Attempted Questions: ${answerSheet?.length}`
                    : `उत्तर दिये गये प्रश्नों की संख्या: ${answerSheet?.length}`}
                </div>
              </div>
            </div>
          </Paper>
          <div className="col-md-12 p-0 mt-md-2">
            <Paper className="quizheadeing p-1 my-1" elevation={2}>
              {(!language.loading && language?.language == "ENGLISH") ||
                localStorageLanguage == "ENGLISH" ? (
                <>
                  <h5 className="m-1 fw-bold portalHeading">
                    {Practicedata?.PracticeTitle_E}
                  </h5>
                </>
              ) : (
                <>
                  <h5 className="m-1 fw-bold  portalHeading">
                    {Practicedata?.PracticeTitle_H}
                  </h5>
                </>
              )}
            </Paper>
          </div>
          <div className="col-md-12 mt-2 p-0">
            {DisplayQue?.QuestionId && (
              <Paper elevation={2} className="d-flex gap-2">
                <div className="mt-1 m-0 p-0">
                  <div
                    onClick={scrollLeft}
                    className="m-1 p-1"
                    style={{
                      width: "40px",
                      height: "40px",
                      border: "1px solid #2b6777",
                      borderRadius: "10px",
                      backgroundColor: "#2b6777",
                      textAlign: "center",
                      color: "white",
                      cursor: "pointer",
                    }}
                  >
                    &lt;
                  </div>
                </div>
                <div
                  className="my-1 w-100 hiddenscrolll"
                  style={{ overflow: "auto" }}
                  ref={containerRef}
                >
                  <div
                    className=" ms-2 hiddenleftcorner "
                    style={{ width: Practicedata?.TotalQusetion * 55 }}
                  >
                    <div className="d-flex  flex-wrap gap-4 py-2 pe-1">
                      {PracticeQueList?.map((val, i) => {
                        return (
                          <div
                            key={i}
                            className={
                              answerSheet?.findIndex(
                                (answer) =>
                                  answer?.QuestionId == val?.QuestionId
                              ) !== -1
                                ? `highlited  quetionsBoxes`
                                : "unhighlited quetionsBoxes"
                            }
                            style={
                              queIndex === i
                                ? {
                                  border: "3px solid ",
                                  backgroundColor: "green",
                                  color: "white",
                                }
                                : {}
                            }
                            onClick={() => {
                              Tabmenu(i);
                            }}
                          >
                            {i + 1}
                          </div>
                        );
                      })}
                    </div>
                  </div>
                </div>
                <div className="mt-1 m-0 p-0">
                  <div
                    onClick={scrollRight}
                    className="m-1 p-1"
                    style={{
                      width: "40px",
                      height: "40px",
                      border: "1px solid #2b6777",
                      borderRadius: "10px",
                      backgroundColor: "#2b6777",
                      textAlign: "center",
                      color: "white",
                      cursor: "pointer",
                    }}
                  >
                    &gt;
                  </div>
                </div>
              </Paper>
            )}
            <div className="mt-2">
              {PracticeQueList.length > 0 ? (
                <Format001
                  question={DisplayQue}
                  quesNo={queIndex+1}
                  answerUpdate={answerSubmit}
                  HindiAnswer={
                    localStorageLanguage == "HINDI" && Answer?.HindiAnswer
                  }
                  EnglishAnswer={
                    localStorageLanguage == "ENGLISH" && Answer?.EnglishAnswer
                  }
                  // answer={Answer}
                  isRead={false}
                />
              ) : (
                "Loading..."
              )}
            </div>
            <Paper
              className="mb-3 my-2 p-2 d-flex justify-content-between"
              elevation={2}
            >
              <Button
                variant="contained"
                color="success"
                disabled={isLoading || disabled || queIndex == 0}
                onClick={Previous}
                size="small"
                className="m-0 py-1 px-3 practiceButton capitalised"
              >
                {(!language.loading && language?.language == "ENGLISH") ||
                  localStorageLanguage == "ENGLISH"
                  ? "Previous"
                  : "पिछला"}
              </Button>
              <Button
                variant="contained"
                color="success"
                size="small"
                disabled={
                  isLoading ||
                  disabled ||
                  queIndex == PracticeQueList.length - 1
                }
                onClick={Submit}
                className="m-0 py-1 px-3 practiceButton capitalised"
              >
                {(!language.loading && language?.language == "ENGLISH") ||
                  localStorageLanguage == "ENGLISH"
                  ? "Next"
                  : "अगला"}
              </Button>
            </Paper>
          </div>
          <div className="col-md-12 text-center mt-3">
            <Button
              variant="contained"
              color="success"
              size="small"
              disabled={isLoading || disabled}
              onClick={() => setOpen(true)}
              className="m-0 py-1 px-3 practiceButton capitalised"
            >
              {(!language.loading && language?.language == "ENGLISH") ||
                localStorageLanguage == "ENGLISH"
                ? "Submit"
                : "जमा करें"}
            </Button>
          </div>
        </div>

        <Dialog
          open={openModel}
          aria-labelledby="alert-dialog-title"
          aria-describedby="alert-dialog-description"
        >
          <DialogContent className="dialog_container p-2">
            <h3
              style={{
                borderRadius: "5px",
                backgroundColor: "var(--dark)",
                padding: "10px",
                color: "#fff",
              }}
              className="text-center"
            >
              {(!language.loading && language?.language == "ENGLISH") ||
                localStorageLanguage == "ENGLISH"
                ? "Congratulations!"
                : "बधाई हो!"}
            </h3>
            <hr />
            <span className="fw-bold text-center ms-3 text-secondary">
              {(!language.loading && language?.language == "ENGLISH") ||
                localStorageLanguage == "ENGLISH"
                ? `Attempted: ${PracticeLogs?.correctAns + PracticeLogs?.wrongAns
                }`
                : `उत्तर दिया: ${PracticeLogs?.correctAns + PracticeLogs?.wrongAns
                }`}
            </span>
            <span className="fw-bold text-center ms-2 text-success">
              {(!language.loading && language?.language == "ENGLISH") ||
                localStorageLanguage == "ENGLISH"
                ? `Correct: ${PracticeLogs?.correctAns}`
                : `सही : ${PracticeLogs?.correctAns}`}
            </span>
            <span className="fw-bold text-center ms-2 text-danger">
              {(!language.loading && language?.language == "ENGLISH") ||
                localStorageLanguage == "ENGLISH"
                ? `Incorrect: ${PracticeLogs?.wrongAns}`
                : `गलत : ${PracticeLogs?.wrongAns}`}
            </span>
            <hr />
            {(!language.loading && language?.language == "ENGLISH") ||
              localStorageLanguage == "ENGLISH" ? (
              <>
                <p className="fw-bold text-center m-0">
                  You have completed this practice question paper.
                </p>
                <p className="fw-bold text-center text-secondary mt-3 mb-1">
                  Please Select The Next Option.
                </p>
              </>
            ) : (
              <>
                <p className="fw-bold text-center m-0">
                  आपने यह अभ्यास प्रश्न पत्र पूरा कर लिया है।
                </p>
                <p className="fw-bold text-center text-secondary mt-3 mb-1">
                  कृपया अगले विकल्प का चयन करें।
                </p>
              </>
            )}
            <div className="d-flex gap-5 justify-content-center mb-3">
              <Button
                variant="contained"
                color="primary"
                size="small"
                className="practiceButton capitalised"
                onClick={() =>
                  router.push(
                    `/practice/result?PracticeId=${params?.id}&PracticeSheetId=${PracticeLogs?.PracticeSheetId}&subjectId=${Practicedata?.SubjectId}`
                  )
                }
              >
                {(!language.loading && language?.language == "ENGLISH") ||
                  localStorageLanguage == "ENGLISH"
                  ? "Practice Result"
                  : "अभ्यास परिणाम"}
              </Button>
              <Button
                variant="contained"
                color="primary"
                size="small"
                className="practiceButton capitalised"
                onClick={() =>
                  router.push(
                    `/practice/practicelist?id=${Practicedata?.SubjectId}`
                  )
                }
              >
                {(!language.loading && language?.language == "ENGLISH") ||
                  localStorageLanguage == "ENGLISH"
                  ? "Go Practice List page"
                  : "अभ्यास सूची पृष्ठ पर जाए"}
              </Button>
            </div>
          </DialogContent>
        </Dialog>

        <Dialog
          open={open}
          aria-labelledby="alert-dialog-title"
          aria-describedby="alert-dialog-description"
        >
          {(!language.loading && language?.language == "ENGLISH") ||
            localStorageLanguage == "ENGLISH" ? (
            <DialogContent className="dialog_container p-2">
              <h6 className=" my-3 text-danger text-center fw-bold">
                Do you want to submit this practice question paper?
              </h6>
              <div className="d-flex justify-content-center mb-3">
                <Button
                  onClick={handleClose}
                  variant="contained"
                  className="cancel_button mx-3 capitalised"
                  size="small"
                >
                  No
                </Button>
                <Button
                  onClick={finalSubmit}
                  variant="contained"
                  className="submit_button capitalised"
                  disabled={answerSheet?.length <= 0}
                  size="small"
                >
                  Yes
                </Button>
              </div>
            </DialogContent>
          ) : (
            <DialogContent className="dialog_container">
              <h5 className="mx-5 my-3 text-danger fw-bold">
                क्या आप यह अभ्यास प्रश्न पत्र जमा करना चाहते हैं?
              </h5>
              <div className="d-flex justify-content-center">
                <Button
                  onClick={handleClose}
                  variant="contained"
                  className="cancel_button mx-3"
                  size="small"
                >
                  नहीं
                </Button>
                <Button
                  onClick={finalSubmit}
                  variant="contained"
                  className="submit_button"
                  size="small"
                >
                  हाँ
                </Button>
              </div>
            </DialogContent>
          )}
        </Dialog>
      </div>
    </div>
  );
};

export default PracticePortal;
