"use client"
import React, { useEffect, useState } from 'react'
import "./profile.css"
import TextField from '@mui/material/TextField';
import CircularProgress from '@mui/material/CircularProgress';
import AuthServices from '@/Services/AuthServices';
import stateList from "../../json/country.json";
import InputLabel from '@mui/material/InputLabel';
import MenuItem from '@mui/material/MenuItem';
import FormControl from '@mui/material/FormControl';
import Select from '@mui/material/Select';
import { toast } from 'react-toastify';
import { useSelector } from 'react-redux';

const Profile = () => {
    const [loading, setloading] = useState(false)
    // const [CountryState, setCountryState] = useState('');
    const [userInfoDetails, setuserInfoDetails] = useState({})

    // states to set data
    const [Id, setId] = useState(null)
    const [firstName, setfirstName] = useState("")
    const [lastName, setlastName] = useState("")
    const [email, setemail] = useState("")
    const [phone, setphone] = useState("")
    const [dob, setdob] = useState(null)
    const [gender, setgender] = useState("")
    const [address, setaddress] = useState("")
    const [city, setcity] = useState("")
    const [pincode, setpincode] = useState(null)
    const [state, setstate] = useState("")
    const language = useSelector((state) => state.language)
    const [localStorageLanguage, setlocalStorageLanguage] = useState(null)



    const updateProfileHandeler = () => {
        setloading(true)
        const formData = {
            firstName: firstName,
            lastName: lastName,
            phone: phone,
            dob: dob,
            gender: gender,
            address: address,
            city: city,
            // pincode:pincode,
            state: state
        }
        AuthServices.userProfileUpdate(formData, Id).then(({ data }) => {
            if (data.success) {
                toast.success(data.message)
                setloading(false)
            }
        }).catch((err) => {
            console.log(err);
            setloading(false)
        })
    }



    useEffect(() => {
        const localStorageLanguage = typeof localStorage !== 'undefined' ? localStorage.getItem('language') : null;
        setlocalStorageLanguage( localStorageLanguage) 
        AuthServices.userProfileData().then(({ data }) => {
            setuserInfoDetails(data.userinfo[0]);
            if (data?.success) {
                setId(data.userinfo[0].Id)
                setfirstName(data?.userinfo[0]?.FirstName)
                setlastName(data?.userinfo[0]?.LastName)
                setgender(data?.userinfo[0]?.Gender)
                setemail(data?.userinfo[0]?.Email)
                setphone(data?.userinfo[0]?.Phone)
                setdob(data?.userinfo[0]?.Dob?.slice(0, 10))
                setaddress(data?.userinfo[0]?.Address)
                setstate(data?.userinfo[0]?.State)
                setcity(data?.userinfo[0]?.City)
                // setpincode(data?.userinfo[0]?.Zip)



            }
        })
    }, [])

    return (
        <>
        {(!language.loading && language?.language == "ENGLISH") || (localStorageLanguage == "ENGLISH") ? 
        <div className='container px-md-5'>
            <div className='profile_wrapper'>
                <div className='row m-0 p-0'>
                    <div className='col-md-5 profile_image_div'>
                        <img src='/image/profile.svg' alt='pic' />
                    </div>
                    <div className='col-md-7 m-0 p-0 p-md-3'>
                        <div className='d-flex justify-content-between p-3'><h5>Profile</h5><h3>Vijayam</h3></div>
                        <div className='row m-0'>
                            <div className='col-md-6 mb-4'>
                                <TextField
                                    label="FirstName"
                                    name='firstName'
                                    size="small"
                                    fullWidth
                                    value={firstName}
                                    onChange={(e) => setfirstName(e.target.value)}
                                />
                            </div>
                            <div className='col-md-6 mb-4'>
                                <TextField
                                    label="LastName"
                                    size="small"
                                    name='lastName'
                                    value={lastName}
                                    fullWidth
                                    onChange={(e) => setlastName(e.target.value)}
                                />
                            </div>
                            <div className='col-md-6 mb-4'>
                                <FormControl fullWidth size="small">
                                    <InputLabel id="demo-select-small-label">Gender</InputLabel>
                                    <Select
                                        labelId="demo-select-small-label"
                                        value={gender}
                                        name='gender'
                                        label="Gender"
                                        onChange={(e) => setgender(e.target.value)}
                                    >

                                        <MenuItem value="male">Male</MenuItem>
                                        <MenuItem value="female">Female</MenuItem>
                                        <MenuItem value="other">Other</MenuItem>
                                    </Select>
                                </FormControl>
                            </div>
                            <div className='col-md-6 mb-4'>
                                <TextField
                                    label="Email"
                                    name='email'
                                    size="small"
                                    fullWidth
                                    value={email}
                                    disabled
                                />
                            </div>
                            <div className='col-md-6 mb-4'>
                                <TextField
                                    label="Phone"
                                    name='phone'
                                    size="small"
                                    value={phone}
                                    fullWidth
                                    type='number'
                                    onChange={(e) => setphone(e.target.value)}
                                />
                            </div>

                            <div className='col-md-6 mb-4'>
                                <TextField
                                    label="DOB"
                                    name='dob'
                                    size="small"
                                    fullWidth
                                    type='date'
                                    focused={dob?.length > 0 && true}
                                    value={dob}
                                    onChange={(e) => setdob(e.target.value)}
                                />
                            </div>
                            <div className='col-md-12 mb-4'>
                                <TextField
                                    label="Address"
                                    name='address'
                                    size="small"
                                    fullWidth
                                    value={address}
                                    onChange={(e) => setaddress(e.target.value)}
                                />
                            </div>
                            <div className='col-md-6 mb-4'>
                                <FormControl fullWidth size="small">
                                    <InputLabel id="demo-select-small-label">State</InputLabel>
                                    <Select
                                        labelId="demo-select-small-label"
                                        value={state}
                                        label="State"
                                        onChange={(e) => setstate(e.target.value)}
                                    >

                                        {stateList.map((ele, i) => {
                                            return <MenuItem key={i} value={ele.title}>{ele.title}</MenuItem>
                                        })}
                                    </Select>
                                </FormControl>
                            </div>
                            <div className='col-md-6 mb-4'>
                                <TextField
                                    label="City"
                                    size="small"
                                    fullWidth
                                    value={city}
                                    onChange={(e) => setcity(e.target.value)}
                                />
                            </div>
                            {/* <div className='col-md-6 mb-4'>
                                <TextField
                                    label="Pincode"
                                    type='number'
                                    name="pincode"
                                    size="small"
                                    value={pincode}
                                    fullWidth   
                                    onChange={(e) => setpincode(e.target.value)}
                                />
                            </div> */}

                        </div>

                        <div className='d-flex justify-content-center mb-4'>
                            <button className='submit_button update_button d-flex' disabled={loading} onClick={() => updateProfileHandeler()}>{loading ? "updating ...." : "Update"}</button>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        :
        <div className='container px-md-5'>
            <div className='profile_wrapper'>
                <div className='row m-0 p-0'>
                    <div className='col-md-5 profile_image_div'>
                        <img src='/image/profile.svg' alt='pic' />
                    </div>
                    <div className='col-md-7 m-0 p-0 p-md-3'>
                        <div className='d-flex justify-content-between p-3'><h5>प्रोफ़ाइल</h5><h3>Vijayam</h3></div>
                        <div className='row m-0'>
                            <div className='col-md-6 mb-4'>
                                <TextField
                                    label="पहला नाम"
                                    name='firstName'
                                    size="small"
                                    fullWidth
                                    value={firstName}
                                    onChange={(e) => setfirstName(e.target.value)}
                                />
                            </div>
                            <div className='col-md-6 mb-4'>
                                <TextField
                                    label="LastName"
                                    size="small"
                                    name='उपनाम'
                                    value={lastName}
                                    fullWidth
                                    onChange={(e) => setlastName(e.target.value)}
                                />
                            </div>
                            <div className='col-md-6 mb-4'>
                                <FormControl fullWidth size="small">
                                    <InputLabel id="demo-select-small-label">Gender</InputLabel>
                                    <Select
                                        labelId="demo-select-small-label"
                                        value={gender}
                                        name='gender'
                                        label="लिंग"
                                        onChange={(e) => setgender(e.target.value)}
                                    >

                                        <MenuItem value="male">Male</MenuItem>
                                        <MenuItem value="female">Female</MenuItem>
                                        <MenuItem value="other">Other</MenuItem>
                                    </Select>
                                </FormControl>
                            </div>
                            <div className='col-md-6 mb-4'>
                                <TextField
                                    label="ईमेल"
                                    name='email'
                                    size="small"
                                    fullWidth
                                    value={email}
                                    disabled
                                />
                            </div>
                            <div className='col-md-6 mb-4'>
                                <TextField
                                    label="मोबाइल नंबर"
                                    name='phone'
                                    size="small"
                                    value={phone}
                                    fullWidth
                                    type='number'
                                    onChange={(e) => setphone(e.target.value)}
                                />
                            </div>

                            <div className='col-md-6 mb-4'>
                                <TextField
                                    label="जन्म तिथि"
                                    name='dob'
                                    size="small"
                                    fullWidth
                                    type='date'
                                    focused={dob?.length > 0 && true}
                                    value={dob}
                                    onChange={(e) => setdob(e.target.value)}
                                />
                            </div>
                            <div className='col-md-12 mb-4'>
                                <TextField
                                    label="पता"
                                    name='address'
                                    size="small"
                                    fullWidth
                                    value={address}
                                    onChange={(e) => setaddress(e.target.value)}
                                />
                            </div>
                            <div className='col-md-6 mb-4'>
                                <FormControl fullWidth size="small">
                                    <InputLabel id="demo-select-small-label">State</InputLabel>
                                    <Select
                                        labelId="demo-select-small-label"
                                        value={state}
                                        label="राज्य"
                                        onChange={(e) => setstate(e.target.value)}
                                    >

                                        {stateList.map((ele, i) => {
                                            return <MenuItem key={i} value={ele.title}>{ele.title}</MenuItem>
                                        })}
                                    </Select>
                                </FormControl>
                            </div>
                            <div className='col-md-6 mb-4'>
                                <TextField
                                    label="शहर"
                                    size="small"
                                    fullWidth
                                    value={city}
                                    onChange={(e) => setcity(e.target.value)}
                                />
                            </div>
                            {/* <div className='col-md-6 mb-4'>
                                <TextField
                                    label="Pincode"
                                    type='number'
                                    name="pincode"
                                    size="small"
                                    value={pincode}
                                    fullWidth   
                                    onChange={(e) => setpincode(e.target.value)}
                                />
                            </div> */}

                        </div>

                        <div className='d-flex justify-content-center mb-4'>
                            <button className='submit_button update_button d-flex' disabled={loading} onClick={() => updateProfileHandeler()}>{loading ? "अद्यतीकरण ...." : "अद्यतन"}</button>
                        </div>
                    </div>
                </div>
            </div>
        </div>
                        }
        </>
    )
}

export default Profile