// "use client"
// import Quiz from '@/component/quiz/Quiz'
// import {  useSearchParams } from 'next/navigation'
// import React from 'react'
// const Page = () => {

//   const params = useSearchParams()
//   return (
//     <div>
//         <Quiz id={params.get('id')}/>
//     </div>
//   )
// }

// export default Page

"use client";
import SubjectTreeServices from "@/Services/SubjectTreeServices";
import React, { useEffect, useState } from "react";
import "./quiz.css";
import "../../app/PracticeQuestions/practice.css";
import Loader from "@/component/common/Loader";
import QuizServices from "@/Services/QuizServices";
import { useRouter, useSearchParams } from "next/navigation";
import { toast } from "react-toastify";
import { useSelector } from "react-redux";
import ExamSheetServices from "@/Services/ExamSheetServices";
import { Button, Paper } from "@mui/material";
import { BsXLg } from "react-icons/bs";


const Quiz = () => {
  const user = useSelector((state) => state.loginInfo);
  const router = useRouter();
  const [SubjectList, setSubjectList] = useState([]);
  const params = useSearchParams();
  const [SubjectId, setSubjectId] = useState(params.get('id'));
  const [subject_name, setsubject_name] = useState("");
  const [QuizList, setQuizList] = useState([]);
  const [examList, setExamList] = useState([]);
  const [noquizError, setNoquizError] = useState("");
  const language = useSelector((state) => state.language);
  const [localStorageLanguage, setlocalStorageLanguage] = useState(null);
  const [isSubscription, setisSubscription] = useState(false);
  const latest = params.get("latest");

  function findSubjectByNodeId(nodeId, subjects) {
    for (let i = 0; i < subjects.length; i++) {
      if (subjects[i].NodeId == nodeId) {
        return subjects[i];
      }
    }
    return null;
  }

  useEffect(() => {
    const handleBeforeUnload = (event) => {
      event.preventDefault();
      latest == 'true' ?
        router.push("/") :
        router.replace(
          `/quizQuestions`
        )
    };

    window.addEventListener('popstate', handleBeforeUnload);

    return () => {
      window.removeEventListener('popstate', handleBeforeUnload);
    };
  }, [router]);

  useEffect(() => {
    SubjectTreeServices.getTreeNodeFrontEndQuiz(0).then(({ data }) => {
      setSubjectList(data.tree);
      if (data.tree.length > 0) {
        const sub_Title = findSubjectByNodeId(SubjectId, data?.tree);
        setsubject_name(sub_Title);
      }
    });
  }, [SubjectId]);

  useEffect(() => {
    setisSubscription(user?.userResult?.isSubscription)
  }, []);

  useEffect(() => {

    const localStorageLanguage =
      typeof localStorage !== "undefined"
        ? localStorage.getItem("language")
        : null;
    setlocalStorageLanguage(localStorageLanguage);
    if (SubjectId) {
      QuizServices.getQuizListbyChapterIdforuser(SubjectId)
        .then(({ data }) => {
          setQuizList(data?.quiz);
          setNoquizError("");
          if (data?.quiz?.length > 0) {
            data?.quiz.map((val) => {
              ExamSheetServices.fetchExamSheet(val?.QuizId)
                .then(({ data }) => {
                  setExamList((prevExamList) => [...prevExamList, data?.examSheet]);
                })
                .catch((e) => {
                  console.log(e);
                });
            });
          }
        })
        .catch((err) => {
          setNoquizError(
            err?.response?.data?.message?.length > 0
            && "No Quizzes available for this subject"
          );
          setQuizList([]);
        });
    }

  }, [SubjectId, language]);

  const createExamSheets = async (obj) => {
    try {
      const quizAnwerSheet = await ExamSheetServices.fetchExamSheet(obj?.quizId)     
      if(Object.keys(quizAnwerSheet?.data?.examSheet)?.length<=0){
        const { data } = await ExamSheetServices.createExamSheet(obj);
      if (data.success) {
        router.push(`/examPanel/${obj?.quizId}`);
      } 
      }else{
       const {data}= await ExamSheetServices.ExamSheetSubmit(obj?.quizId)
       
          if (data.success) {
            const { data } = await ExamSheetServices.createExamSheet(obj);
            if (data.success) {
              router.push(`/examPanel/${obj?.quizId}`);
            } 
          }
      }
      
    } catch (error) {
     
      console.log(error);
    }
  };
  const gotoExamPanel = (id, IsPaid) => {
    if (user?.isLoggedIn) {
      if (IsPaid == user?.userResult?.isSubscription) {
        const obj = { quizId: id };
        createExamSheets(obj)
     
      } else if (!IsPaid) {
        const obj = { quizId: id };
        createExamSheets(obj)
        // router.push(`/examPanel/${id}`);
      } else {
        (!language.loading && language?.language == "ENGLISH") ||
          localStorageLanguage == "ENGLISH" ?
          toast.error("Please subscribe Vijayam for this.")
          :
          toast.error("इसके लिए कृपया विजयं की सदस्यता लें।.")
      }
    } else {
      (!language.loading && language?.language == "ENGLISH") ||
        localStorageLanguage == "ENGLISH" ?
        toast.error("Please login on Vijayam for this.")
        :
        toast.error("इसके लिए कृपया विजयं पर लॉग-इन करें।")
    }
  };
  const gotoResult = (id, IsPaid) => {
    if (user?.isLoggedIn) {
      if (IsPaid == user?.userResult?.isSubscription && examList?.find((val) => val?.QuizeId == id)) {
        router.push(`/result?QuizId=${id}`);
      } else if (!IsPaid) {
        router.push(`/result?QuizId=${id}}`);
      } else {
        toast.error("This Quiz is paid. Please subscribe.");
      }
    } else {
      toast.error("Please Login to See Quiz Result.");
    }
  };

  if (!SubjectList?.length > 0) {
    return <Loader />;
  }
  return (
    <div>
      <div className="mt-2">
        <div className="row m-0 p-0">
          {(!language.loading && language?.language == "ENGLISH") ||
            localStorageLanguage == "ENGLISH" ? (
            <div className="col-md-9 container ">
              <Paper elevation={5} className="quiz_back_button p-1 my-2">
                <Button
                  variant="contained"
                  color="success"
                  onClick={() =>
                    latest == 'true' ?
                      router.push("/")
                      :
                      router.push(
                        `/quizQuestions`
                      )
                  }
                  size="small"
                  className="m-1 py-1 px-3 submit_button capitalised"
                >
                  Back To Previous Page
                </Button>
                <h5 className="text-center Subject_Name mb-0 me-2">{subject_name.NodeName_E}</h5>
              </Paper>
              <div className="">
                <div className={`subject_toggle_btn`}>
                  <div className="">Quizzes list</div>
                </div>
              </div>
              <div className="row ">
                {SubjectId &&
                  !noquizError &&
                  QuizList?.map((ele, i) => {
                    return (
                      <div className="col-md-12 ">
                        <div className="subject_card1">
                          <div className="pracice_logo">Q</div>
                          <div className="w-100">
                            <h6 className="ms-3 titlePractic">{ele?.QuizName_English}</h6>
                            <div className="d-flex justify-content-between w-100 px-2">
                              <div className="d-flex">
                                <p className="mx-1 practice_free">
                                  {ele?.TotalQusetion} Question |
                                </p>
                                <span className="mx-1 practice_free">
                                  {ele?.TotalTime} minutes |
                                </span>

                                <p className="mx-1 paid_class">
                                  {ele?.IsPaid ? "Paid" : "Free"}
                                </p>
                              </div>
                            </div>
                            <div className="practice_btn_submit">
                              <Button
                                className="fw-bold cursor capitalised px-2 py-0 mui_btn_font"
                                style={{ color: "#fff", backgroundColor: "var(--dark)" }}
                                variant="contained"
                                onClick={() => gotoExamPanel(ele.QuizId, ele?.IsPaid)}
                              >
                                Start Quiz
                              </Button>
                            </div>
                          </div>
                        </div>
                      </div>
                    );
                  })}

                {SubjectId && noquizError && (
                  <div className="quiz_info">
                    <div className="quiz_info_title text-danger">
                      {" "}
                      {noquizError}
                    </div>
                  </div>
                )}
              </div>
            </div>
          ) : (
            <div className="col-md-9 container ">
              <Paper elevation={5} className="quiz_back_button p-1 my-2"><Button
                variant="contained"
                color="success"
                onClick={() =>
                  latest == 'true' ?
                    router.push("/")
                    :
                    router.push(
                      `/quizQuestions`
                    )
                }
                size="small"
                className="m-1 submit_button"
              >
                पिछले पृष्ठ पर वापस जाए
              </Button>
                <h5 className="text-center Subject_Name mb-0 me-2">{subject_name.NodeName_H}</h5>
              </Paper>
              <div className="d-flex">
                <div className={`subject_toggle_btn `}> प्रश्नोत्तरी सूची</div>
              </div>
              <div className="row">
                {SubjectId &&
                  !noquizError &&
                  QuizList?.map((ele, i) => {
                    return (
                      <div className="col-md-12">
                        <div className="subject_card1">
                          <div className="pracice_logo">प्र</div>
                          <div className="w-100">
                            <h6 className="ms-3 titleQuiz titlePractic">{ele?.QuizName_Hindi}</h6>
                            <div className="QuizCard w-100 px-2">
                              <div className="d-flex">
                                <span className="mx-1 practice_free">
                                  {ele?.TotalQusetion} प्रशन |
                                </span>
                                <span className="mx-1 practice_free">
                                  {ele?.TotalTime} मिनट |
                                </span>
                                <span className="mx-1 paid_class">
                                  {ele?.IsPaid ? "शुल्क" : "निशुल्क"}
                                </span>
                              </div>
                              <div className="practice_btn_submit">
                                <Button
                                  variant="contained"
                                  size="small"
                                  className="m-1 submit_button cursor"
                                  onClick={() => gotoExamPanel(ele.QuizId, ele?.IsPaid)}
                                >
                                  प्रश्नोत्तरी प्रारंभ करें
                                </Button>
                              </div>
                            </div>
                          </div>
                        </div>
                      </div>
                    );
                  })}

                {SubjectId && noquizError && (
                  <div className="quiz_info">
                    <div className="quiz_info_title text-danger">
                      {" "}
                      {noquizError}
                    </div>
                  </div>
                )}
              </div>
            </div>
          )}
        </div>
      </div>
    </div>
  );
};

export default Quiz;
