"use client";
import React, { useEffect, useState } from "react";
import "../../admin/subjectentry/subjectentry.css";
import "../subjectwise.css";
import SubjectTreeServices from "@/Services/SubjectTreeServices";
import { useParams, useRouter, useSearchParams } from "next/navigation";
import Loader from "@/component/common/Loader";
import { FaChevronRight } from "react-icons/fa";
import { useSelector } from "react-redux";
import { Button, IconButton } from "@mui/material";
import { FaChevronDown } from "react-icons/fa";
import { TfiMenuAlt } from "react-icons/tfi";

function TreeNode({ node }) {
  const [isExpanded, setIsExpanded] = useState(false);

  const toggleExpand = () => {
    setIsExpanded(!isExpanded);
  };

  return (
    <li key={node.id} className="chaptr_listt">
      <div style={{ cursor: "pointer" }}>
        <span onClick={toggleExpand}>
          {isExpanded && node.children.length > 0 && <FaChevronDown />}
          {isExpanded || (node.children.length > 0 && <FaChevronRight />)}{" "}
          <a
            href={`#${node?.id}`}
            style={{ textDecoration: "none", color: "blue" }}
          >
            {node.text}
          </a>
        </span>
      </div>
      {isExpanded && node.children.length > 0 && (
        <ul style={{ marginLeft: "7%", listStyleType: "none", padding: 0 }}>
          {node?.children?.map((child) => (
            <li style={{ margin: "0.5rem 0" }} key={child.id}>
              <a
                href={`#${child?.id}`}
                style={{
                  textDecoration: "none",
                  color: "blue",
                }}
              >
                <div className="d-flex">
                  <p className="me-2 m-0 p-0">{isExpanded && "•"}</p>{" "}
                  <p className="m-0 p-0">{child.text}</p>
                </div>
              </a>
            </li>
          ))}
        </ul>
      )}
    </li>
  );
}

function TreeView({ data }) {
  return (
    <ul style={{ listStyleType: "none", padding: 0, margin: 0, color: "red" }}>
      {data.map((node) => (
        <TreeNode key={node.id} node={node} />
      ))}
    </ul>
  );
}

export default function ChapterTreeComponent() {
  const [nodeData, setNodeData] = useState([]);
  const [chapterId, setchapterId] = useState(null);
  const [chapterList, setChapterList] = useState([]);
  const router = useRouter();
  const params = useSearchParams();
  const id = params.get("Id");
  const ParentId = params.get("ParentId");
  const [cptrId, setcptrId] = useState(params.get("Id"));
  const [chapterName_H, setchapterName_H] = useState(params.get("chap_name_H"));
  const [chapterName_E, setchapterName_E] = useState(params.get("chap_name_E"));
  const language = useSelector((state) => state.language);
  const [localStorageLanguage, setlocalStorageLanguage] = useState(null);
  const [isLoading, setIsLoading] = useState(true);
  const [Content, setContent] = useState("");
  const [updatedHtml, setUpdatedHtml] = useState(null);
  const [HeadingText, setHeadingText] = useState([]);
  const [Togglesidebar, setTogglesidebar] = useState(true);

  useEffect(() => {
    setIsLoading(true);
    const localStorageLanguage =
      typeof localStorage !== "undefined"
        ? localStorage.getItem("language")
        : null;

    setlocalStorageLanguage(localStorageLanguage);
    setIsLoading(false);
  }, [language]);

  function mergeData(existingData, newData) {
    const uniqueNodeIds = new Set(existingData.map((item) => item.NodeId));
    const filteredNewData = newData.filter(
      (item) => !uniqueNodeIds.has(item.NodeId)
    );
    return [...existingData, ...filteredNewData];
  }
  const buildTree = (menuItems, parentID) => {
    return menuItems
      .filter((menu) => menu.ParentId === parentID)
      .map((menu) => {
        const children = buildTree(menuItems, menu.NodeId);
        if (children.length > 0) {
          menu.children = children;
        }
        return menu;
      });
  };

  const menuTreeData = buildTree(nodeData, Number(cptrId));

  const onhandleId = (id) => {
    setchapterId(id);
  };
  useEffect(() => {
    setIsLoading(true);
    const localStorageLanguage =
      typeof localStorage !== "undefined"
        ? localStorage.getItem("language")
        : null;
    setlocalStorageLanguage(localStorageLanguage);
    SubjectTreeServices.singleContent(
      chapterId || cptrId || menuTreeData[0]?.NodeId
    )
      .then(({ data }) => {
        setContent(data?.data);
        setIsLoading(false);
      })
      .catch((err) => {
        setContent("");
        console.log(err?.response?.data?.error);
        setIsLoading(false);
      });
  }, [chapterId || cptrId || menuTreeData[0]?.NodeId]);

  useEffect(() => {
    const updateContent = () => {
      const tempDiv = document.createElement("div");
      tempDiv.innerHTML =
        (!language?.loading && language?.language === "ENGLISH") ||
          localStorageLanguage === "ENGLISH"
          ? Content?.Description_E
          : Content?.Description_H;

      const headingElements = tempDiv.querySelectorAll("h3, h4");
      const newHeadings = [];
      let currentH3 = null;

      headingElements.forEach((headingElement) => {
        const tagName = headingElement.tagName.toLowerCase();
        const headingText = headingElement.textContent.trim();
        const headingId = headingText.toLowerCase().replace(/\s+/g, "-");
        if (tagName === "h3") {
          currentH3 = { text: headingText, id: headingId, children: [] };
          newHeadings.push(currentH3);
        } else if (tagName === "h4" && currentH3) {
          const headingData = { text: headingText, id: headingId };
          currentH3.children.push(headingData);
        }

        headingElement.id = headingId;
      });

      // Select all table elements with the class for responsive
      const tables = tempDiv.querySelectorAll(".MsoTableGrid");

      tables.forEach((table) => {
        let parentDiv = table.previousElementSibling;

        if (!parentDiv || !parentDiv.id === "parentDiv") {
          parentDiv = document.createElement("div");
          parentDiv.className = "parentDiv";
          parentDiv.style.overflow = "auto";
          parentDiv.style.width = "100%";
          parentDiv.style.height = "auto";
          table.parentNode.insertBefore(parentDiv, table);
        }
        parentDiv.appendChild(table);
      });

      setHeadingText(newHeadings);
      setUpdatedHtml(tempDiv.innerHTML);
    };

    updateContent();
  }, [
    Content,
    (!language?.loading && language?.language == "ENGLISH") ||
    localStorageLanguage == "ENGLISH",
  ]);

  const toggleSidebar = () => {
    if (Togglesidebar == false) {
      setTogglesidebar(true);
    } else {
      setTogglesidebar(false);
    }
  };
  if (isLoading) {
    return <Loader />;
  }

  return (
    <div
      className="mx-md-5 my-md-3 pt-2"
      style={{ boxShadow: "inset 2px 2px 20px var(--light)" }}
    >
      {/*//=================================//
              //     this is english section     //
             //=================================// */}
      <div className="row m-0">
        <div className="col-md-3 col-12 contant_button  text-center">
          <Button
            variant="contained"
            color="success"
            onClick={() =>
              ParentId
                ? router.push(`/subjectwise/chapterlist/${ParentId}`)
                : router.push("/")
            }
            size="small"
            className="m-1 p-1 submit_button capitalised"
          >
            {(!language.loading && language?.language == "ENGLISH") ||
              localStorageLanguage == "ENGLISH"
              ? "Back to previous page"
              : "पिछले पृष्ठ पर वापस जाए"}
          </Button>
        </div>
        <div className="col-md-9 col-12">
          {(!language.loading && language?.language == "ENGLISH") ||
            localStorageLanguage == "ENGLISH" ? (
            <div>
              {Togglesidebar == true && (
                <div className="mb-2  text-center" style={{
                  fontSize: "22px",
                  display: "flex",
                  alignItems: "center",
                  justifyContent: "center",
                  width: "100%"
                }}>
                  <strong>{chapterName_E}</strong>
                </div>
              )}
              {Togglesidebar !== true && (
                <div className="">
                  {/* this code for Open to Side Bar Menu //  Back to Units/chapter list  */}
                  <div className="mb-2 topic_content_head">
                    <IconButton onClick={toggleSidebar} title="Show Side Bar">
                      <TfiMenuAlt />
                    </IconButton>

                    <strong className="text-center">{chapterName_E}</strong>

                  </div>
                </div>
              )}
            </div>
          ) : (
            <div>
              {Togglesidebar == true && (
                <div className="mb-2  text-end" style={{
                  fontSize: "22px",
                  display: "flex",
                  alignItems: "center",
                  justifyContent: "center",
                  width: "100%"
                }}>
                  <strong>{chapterName_H}</strong>
                </div>
              )}
              {Togglesidebar !== true && (
                <div className="">
                  {/* this code for Open to Side Bar Menu //  Back to Units/chapter list  */}
                  <div className=" topic_content_head p-0 mb-2 ">
                    <IconButton onClick={toggleSidebar} title="साइडबार पर जाए">
                      <TfiMenuAlt />
                    </IconButton>
                    <strong>{chapterName_H}</strong>
                  </div>
                </div>
              )}
            </div>
          )}
        </div>
      </div>

      {(!language?.loading && language?.language == "ENGLISH") ||
        localStorageLanguage == "ENGLISH" ? (
        <div className="row m-0 mt-1 p-0 d-flex">
          {Togglesidebar ? (
            <>
              <div className="col-md-3 p-0 m-0 topics_div">
                <div className="topics_title tableOfContent p-0 m-0">
                  <div className="m-0 p-0 d-flex  align-items-center">
                    <IconButton
                      onClick={toggleSidebar}
                      title="Hide side bar"
                      style={{ width: "35px", color: "white" }}
                    >
                      <TfiMenuAlt />
                    </IconButton>
                    <h6 className=" m-0 p-0 text-center">
                      Table of Contents
                    </h6>
                  </div>
                </div>
                <TreeView data={HeadingText} />
              </div>
            </>
          ) : (
            ""
          )}

          <div className={`col-md-9 mt-1 p-2 container text-center`}>
            <div
              className="topic_content"
              style={{ scrollBehavior: "smooth", scrollPaddingTop: "100px" }}
            >
              {Content ? (
                <div className="contentDiv">
                  <div dangerouslySetInnerHTML={{ __html: updatedHtml }} />
                </div>
              ) : (
                <div className="chaperNot_found">loading...</div>
              )}
            </div>
          </div>
        </div>
      ) : (
        //=================================//
        //     this is hindi section       //
        //=================================//
        <div className="row m-0 d-flex">
          {Togglesidebar ? (
            <div className="col-md-3 p-0 m-0 topics_div">
              <div className="topics_title tableOfContent m-0 p-0">
                <div className="m-0 p-0 d-flex  align-items-center">
                  <IconButton
                    onClick={toggleSidebar}
                    title="साइडबार छुपाएँ"
                    style={{ width: "35px", color: "white" }}
                  >
                    <TfiMenuAlt />
                  </IconButton>
                  <h6 className=" m-0 p-0 text-center">विषयसूची
                  </h6>
                  {/* <h5 className="ms-5 table_head  " style={{ color: "black" }}>
                    विषयसूची
                  </h5> */}
                </div>
              </div>
              <TreeView data={HeadingText} />
            </div>
          ) : (
            ""
          )}
          <div className={`col-md-9 mt-1 p-2 container text-center`}>
            <div className="topic_content">
              {Content ? (
                <div className="contentDiv">
                  <div dangerouslySetInnerHTML={{ __html: updatedHtml }} />
                </div>
              ) : (
                <div className="chaperNot_found">loading...</div>
              )}
            </div>
          </div>
        </div>
      )}
    </div>
  );
}
