
import React, { forwardRef, useImperativeHandle, useRef } from "react";
import { CircularProgress, Button, Paper } from "@mui/material";
import "@/app/practice/practice.css";

const QuetionTabMenu = forwardRef(({
  isLoading,
  questionData,
  displayQue,
  answerSheet,
  showQuestions,
  currentQuestionIndex,
}, ref) => {
  const containerRef = useRef(null);
  const scrollLeft = () => {
    containerRef.current.scrollBy({ left: -50, behavior: "smooth" });
  };

  const scrollRight = () => {
    containerRef.current.scrollBy({ left: 50, behavior: "smooth" });
  };

  useImperativeHandle(ref, () => ({
    scrollRight,
    scrollLeft
  }));

  return (
    <div className="row m-0">
      <div className="col-md-12"></div>
      {displayQue?.QuestionId && (
        <Paper elevation={2} className="d-flex ">
          <div className="mt-1 m-0 p-0">
            <div
              onClick={scrollLeft}
              className="m-1 p-1"
              style={{ width: "40px", height: "40px", border: "1px solid #2b6777", borderRadius: "10px", backgroundColor: "#2b6777", textAlign: "center", color: "white", cursor: "pointer" }}
            >
              &lt;
            </div>
          </div>
          <div
            className="my-1 w-100 hiddenscrolll"
            style={{ overflow: "auto" }}
            ref={containerRef}
          >
            <div
              className="ms-2 hiddenleftcorner"
              style={{ width: questionData?.length * 55 }}
            >
              <div className="d-flex flex-wrap gap-2 gap-md-4 py-2 pe-1">
                {questionData?.map((val, i) => {
                  return (
                    <div
                      key={i}
                      className={
                        answerSheet?.length > 0 && answerSheet?.findIndex(
                          (answer) => answer?.QuestionId == val?.QuestionId
                        ) !== -1
                          ? `highlited quetionsBoxes`
                          : "unhighlited quetionsBoxes"
                      }
                      style={
                        currentQuestionIndex == i
                          ? {
                            border: "3px solid",
                            backgroundColor: "green",
                            color: "white",
                          }
                          : {}
                      }
                      onClick={() => !isLoading && showQuestions("toggle", i, null)}
                    >
                      {(isLoading && currentQuestionIndex == i) ? <CircularProgress size={15} thickness={8}  
                        sx={{
                          color: '#fff',
                        }} /> : i + 1}
                    </div>
                  );
                })}
              </div>
            </div>
          </div>
          <div className="mt-1 m-0 p-0">
            <div
              onClick={scrollRight}
              className="m-1 p-1"
              style={{ width: "40px", height: "40px", border: "1px solid #2b6777", borderRadius: "10px", backgroundColor: "#2b6777", textAlign: "center", color: "white", cursor: "pointer" }}
            >
              &gt;
            </div>
          </div>
        </Paper>
      )}
    </div>
  );
});

export default QuetionTabMenu;

