// import { useEffect, useState } from "react";

// function useFullScreen() {
//     const [isFullScreen, setFullScreen] = useState(false);

//     function detectFullScreenChange() {
//         console.log("called");
//         const isInFullScreen = (document.fullScreenElement && document.fullScreenElement !== null) || (document.mozFullScreen || document.webkitIsFullScreen || document.msFullscreenElement);
//         setFullScreen(isInFullScreen);
//     }
   
//     function cancelFullScreen() {
//         const el = document;
//         const requestMethod = el.cancelFullScreen ||
//             el.webkitCancelFullScreen ||
//             el.mozCancelFullScreen ||
//             el.exitFullscreen ||
//             el.webkitExitFullscreen;
//         if (requestMethod) {
//             // cancel full screen.
//             requestMethod?.call(el);
//             setFullScreen(false);
//         } else {
//             throw new Error("Browser Doesn't Support FullScreen");
//         }
//     }
//     function requestFullScreen() {
//         const element = document.body;
//         const requestMethod =
//             element.requestFullScreen ||
//             element.webkitRequestFullScreen ||
//             element.mozRequestFullScreen ||
//             element.msRequestFullScreen;
//             // element.style.backgroundColor = '#ffff';

//         if (requestMethod) {
//             // Native full screen.
//             requestMethod?.call(element);
//             setFullScreen(true);
//         } else {
//             throw new Error("Browser Doesn't Support FullScreen");
//         }
//     }

//     return [isFullScreen, requestFullScreen, cancelFullScreen];
// }

// export default useFullScreen;

import { useEffect, useState } from "react";

function useFullScreen() {
    const [isFullScreen, setFullScreen] = useState(false);

    function detectFullScreenChange() {
        const isInFullScreen = !!(
            document.fullscreenElement ||
            document.mozFullScreenElement ||
            document.webkitFullscreenElement ||
            document.msFullscreenElement
        );
        setFullScreen(isInFullScreen);
    }

    useEffect(() => {
        document.addEventListener("fullscreenchange", detectFullScreenChange);
        document.addEventListener("webkitfullscreenchange", detectFullScreenChange);
        document.addEventListener("mozfullscreenchange", detectFullScreenChange);
        document.addEventListener("MSFullscreenChange", detectFullScreenChange);

        const handleKeydown = (event) => {
            if (event.key === "F11") {
                // Timeout is needed to allow the browser to complete its full-screen action
                setTimeout(detectFullScreenChange, 100);
            }
        };
        window.addEventListener("keydown", handleKeydown);

        return () => {
            document.removeEventListener("fullscreenchange", detectFullScreenChange);
            document.removeEventListener("webkitfullscreenchange", detectFullScreenChange);
            document.removeEventListener("mozfullscreenchange", detectFullScreenChange);
            document.removeEventListener("MSFullscreenChange", detectFullScreenChange);
            window.removeEventListener("keydown", handleKeydown);
        };
    }, []);

    function cancelFullScreen() {
        const el = document;
        if (document.fullscreenElement || document.mozFullScreenElement || document.webkitFullscreenElement || document.msFullscreenElement) {
            const requestMethod = el.exitFullscreen ||
                el.webkitExitFullscreen ||
                el.mozCancelFullScreen ||
                el.msExitFullscreen;
            if (requestMethod) {
                requestMethod.call(el);
            } else {
                throw new Error("Browser Doesn't Support FullScreen");
            }
        }
    }

    function requestFullScreen() {
        const element = document.documentElement;
        const requestMethod = element.requestFullscreen ||
            element.webkitRequestFullscreen ||
            element.mozRequestFullScreen ||
            element.msRequestFullscreen;
        if (requestMethod) {
            requestMethod.call(element);
        } else {
            throw new Error("Browser Doesn't Support FullScreen");
        }
    }

    return [isFullScreen, requestFullScreen, cancelFullScreen];
}

export default useFullScreen;
