import * as React from 'react';
import Button from '@mui/material/Button';
import TextField from '@mui/material/TextField';
import Dialog from '@mui/material/Dialog';
import DialogActions from '@mui/material/DialogActions';
import DialogContent from '@mui/material/DialogContent';
import DialogContentText from '@mui/material/DialogContentText';
import DialogTitle from '@mui/material/DialogTitle';
import SubscriptionServices from '@/Services/SubscriptionServices';
import { toast } from 'react-toastify';

export default function PromoDialog({
    open,
    SubscriptionId,
    months,
    Amount
}) {
    const [isOpen, setIsOpen] = React.useState(open);
    const [promoCode, setPromoCode] = React.useState('');
    const [ERROR, setERROR] = React.useState('');
    const [proapply, setproapply] = React.useState('');
    const [TotalAmount, setTotalAmount] = React.useState();
    console.log(TotalAmount)
    const handleClickOpen = () => {
        setIsOpen(true);
    };

    const handleClose = () => {
        setIsOpen(false);
        setPromoCode('')
        setERROR('')
        setproapply('')
        setTotalAmount('')
    };

    const handlePromoCodeChange = (event) => {
        setERROR('')
        setproapply('')
        setTotalAmount('')
        setPromoCode(event.target.value.toUpperCase());
    };
    const verifyPromoCode = () => {
        SubscriptionServices.verifyPromoCode(promoCode, SubscriptionId).then(({ data }) => {
            console.log(data)
            // console.log(Number(data?.result) - Number(Amount))
            setproapply(data?.msg)
            setTotalAmount(data?.result)
        }).catch((error) => {
            setERROR(error.response.data.error)
            console.log(error.response.data.error)
        })
    };
    const goPay = () => {
        const payload = {
            SubscriptionId,
            months,
            promoCode
        }
        SubscriptionServices.GoSubscribe(payload).then(({ data }) => {
            console.log(data)
            toast.success("Subscribe successfully ")
            handleClose()
        }).catch((error) => {
            setERROR(error.response)
            console.log(error.response)
        })
    };
    return (
        <React.Fragment>
            <Button variant="outlined" onClick={handleClickOpen}>
                Have a promo code?
            </Button>
            <Dialog
                open={isOpen}
                onClose={handleClose}
                PaperProps={{
                    component: 'form',
                    onSubmit: (event) => {
                        event.preventDefault();
                        console.log(event)
                        const formData = new FormData(event.currentTarget);
                        const formJson = Object.fromEntries(formData.entries());
                        const Promocode = formJson.PromoCode;

                        handleClose();
                    },
                }}
            >
                <DialogTitle className='fw-bold text-success'>Subscribe using Promo Code</DialogTitle>
                <DialogContent>
                    <DialogContentText>
                        To subscribe to this website, please enter your Promo Code here. We will send updates occasionally.
                        Total Amount :
                        {TotalAmount ? (
                            <>
                                <del className="mr-20" style={{ color: "red" }}>Rs.{Amount.toString()}</del> <span className='text-success'> Rs.{Amount - TotalAmount}</span>
                            </>
                        ) : (
                            <span> Rs.{Amount}</span>
                        )}
                    </DialogContentText>
                    <TextField
                        autoFocus
                        required
                        margin="dense"
                        id="PromoCode"
                        name="PromoCode"
                        label="PromoCode"
                        type="text"
                        fullWidth
                        variant="standard"
                        value={promoCode}
                        onChange={handlePromoCodeChange}
                    />
                    <p style={{ color: "red", fontSize: "15px", fontWeight: "bold" }}>{ERROR}</p>
                    <p style={{ color: "green", fontSize: "15px", fontWeight: "bold" }}>{proapply}</p>
                </DialogContent>
                <DialogActions>
                    <Button onClick={handleClose}>Cancel</Button>
                    {TotalAmount ?
                        <Button onClick={goPay}>Pay now {TotalAmount}</Button>
                        :
                        <Button onClick={verifyPromoCode}>Apply</Button>
                    }
                </DialogActions>
            </Dialog>
        </React.Fragment>
    );
}
