import { Box, Button, SwipeableDrawer } from "@mui/material";
import React, { use, useEffect, useState } from "react";
import QuizServices from "@/Services/QuizServices";
import { toast } from "react-toastify";
import "../../app/admin/quizEntry/quizentry.css";
import "../../app/admin/questionPreview/questionReview.css";
import "../../component/questionFormat/format.css";
import Format001 from "@/component/questionFormat/Format001";
import Pagination from "@mui/material/Pagination";
import Stack from "@mui/material/Stack";

export default function QuizQuestionSlider(props) {
  const [selectedoption, setselectedOption] = useState("");
  const [AutoAddedQuesList, setAutoAddedQuesList] = useState([]);
  const [QuestionList, setQuestionList] = useState([]);
  const [QuesCount, setQuesCount] = useState(null);
  const [CouredQuestion, setCouredQuestion] = useState([]);
  const [currentPage, setCurrentPage] = useState(1);
  const questionsPerPage = 10;
  const [page, setPage] = useState(1);

  const handlePageChange = (event, value) => {
    setCurrentPage(value);
    QuizServices.getQuizwiseAllQuestions(props.QuizId, value)
      .then(({ data }) => {
        setQuestionList(data.questions);
        checkQuesAddedOrDeleted();
      })
      .catch((err) => {
        console.log(err);
      });
  };

  const addAutoQuestions = () => {
    setselectedOption("1");
    QuizServices.autoAddQuestion(props?.QuizId)
      .then(({ data }) => {
        toast.success(data?.message);
        if (data.success) {
          autoaddedquestion();
        }
      })
      .catch((err) => {
        toast.error(err?.response?.data?.error);
      });
  };

  const addManualQuestions = () => {
    setselectedOption("2");
    QuizServices.getQuizwiseAllQuestions(props.QuizId, page)
      .then(({ data }) => {
        setQuestionList(data.questions);
        checkQuesAddedOrDeleted();
      })
      .catch((err) => {
        console.log(err);
      });
  };

  const autoaddedquestion = () => {
    setselectedOption("3");
    QuizServices.getAutoaddedQestion(props.QuizId)
      .then(({ data }) => {
        setAutoAddedQuesList(data?.questions);
      })
      .catch((err) => {
        console.log(err);
      });
  };

  const addManQuesOnClick = (questionId) => {
    const data = {
      quizId: props.QuizId,
      questionId: questionId,
    };
    QuizServices.ManualAddQuestion(data)
      .then(({ data }) => {
        console.log(data);
        props.addedQuestionIds(data.data, props.QuizId)
        checkQuesAddedOrDeleted();
      })
      .catch((err) => {
        toast?.warn(err?.response?.data?.error);
        console.log(err?.response?.data?.error);
      });
  };

  const getCount = () => {
    QuizServices.questionCount(props.QuizId)
      .then(({ data }) => {
        setQuesCount(data.questionCounts[0].QuesCount);
      })
      .catch((err) => {
        console.log(err?.response?.data);
      });
  };

  const checkQuesAddedOrDeleted = () => {
    QuizServices.getOneQuizWithQuestion(props?.QuizId)
      .then(({ data }) => {
        if (data.quizFullDetails.questions.length === 1) {
          setCouredQuestion([data.quizFullDetails.questions]);
        } else {
          setCouredQuestion(data.quizFullDetails.questions.split(","));
        }
      })
      .catch((err) => {
        console.log(err);
        setCouredQuestion([]);
      });
  };

  useEffect(() => {
    if (props.open === false) {
      setselectedOption("");
      setAutoAddedQuesList([]);
      setQuestionList([]);
      setCurrentPage(1);
    }
    if (props.open === true) {
      getCount();
    }
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [props.open]);

  const indexOfLastQuestion = currentPage * questionsPerPage;
  const indexOfFirstQuestion = indexOfLastQuestion - questionsPerPage;
  const currentQuestions = QuestionList.slice(
    indexOfFirstQuestion,
    indexOfLastQuestion
  );

  const list = () => (
    <Box
      sx={{ padding: "70px 10px 10px 10px" }}
      role="presentation"
      className="rowquestuin"
    >
      <div className="d-flex justify-content-between">
        <div>
          <span className="fw-bold mx-3">
            Question list
          </span>
          /
          <span className="fw-bold mx-3">
            प्रश्न सूची
          </span>
        </div>
        <div>
          {/* <Button
            variant="contained"
            className={`submit_button  px-4 ${selectedoption === "1" && "auto_ADD"
              }`}
            size="small"
            onClick={() => {
              addAutoQuestions();
            }}
          >
            Add Auto Question{" "}
          </Button> */}
          <Button
            variant="contained"
            className={`submit_button px-4 ms-3 ${selectedoption === "2" && "auto_ADD"
              }`}
            size="small"
            onClick={() => addManualQuestions()}
          >
            Manual Add Question{" "}
          </Button>
        </div>
      </div>
      <hr />
      {selectedoption === "" && (
        <div>
          <p className="text-center fw-bold mt-5 pt-5">
            Please Select the option to add question{" "}
          </p>
        </div>
      )}

      {selectedoption === "3" && (
        <div className="row m-0">
          {AutoAddedQuesList?.length > 0 &&
            AutoAddedQuesList?.map((ele, i) => {
              return (
                <div className={` col-md-12 p-1`} key={i}>
                  <div
                    className={` m-1 question`}
                    onClick={() => addManQuesOnClick(ele.QuestionId)}
                  >
                    <div className="m-3">
                      {
                        <Format001
                          quesNo={i + 1}
                          question={ele}
                          HindiAnswer={ele?.HindiAnswer}
                          EnglishAnswer={ele?.EnglishAnswer}
                          isRead={true}
                        />
                      }{" "}
                    </div>
                  </div>
                </div>
              );
            })}
        </div>
      )}

      {selectedoption === "2" && (
        <div className="row m-0">
          {currentQuestions?.length > 0 &&
            currentQuestions?.map((ele, i) => {
              return (
                <div
                  className={` col-md-12 p-1 `}
                  key={i}
                  onClick={() => addManQuesOnClick(ele.QuestionId)}
                >
                  <div
                    className={` m-1 ${CouredQuestion?.includes(ele.QuestionId)
                        ? "question "
                        : "questionnot"
                      }`}
                  >
                    <div className="m-3">
                      {
                        <Format001
                          quesNo={indexOfFirstQuestion + i + 1}
                          question={ele}
                          HindiAnswer={ele?.HindiAnswer}
                          EnglishAnswer={ele?.EnglishAnswer}
                          isRead={true}
                        />
                      }{" "}
                    </div>
                  </div>
                </div>
              );
            })}
        </div>
      )}
      <div className="pagination_wrapper">
        {QuestionList?.length > 10 && QuestionList?.length != 0 && (
          <Stack spacing={2}>
            <Pagination
              count={Math.ceil(QuestionList.length / questionsPerPage)}
              page={currentPage}
              className="color_btn"
              onChange={handlePageChange}
              size="large"
            />
          </Stack>
        )}
      </div>
    </Box>
  );

  return (
    <>
      <SwipeableDrawer
        anchor={props.anchor}
        open={props.open}
        onClose={props.onClose}
        onOpen={props.onOpen}
      >
        {list("right")}
      </SwipeableDrawer>
    </>
  );
}
