
"use client";
import React, { useEffect, useState, useRef } from 'react';
import dayjs from 'dayjs';
import 'dayjs/locale/hi';  // Import Hindi locale
import Badge from '@mui/material/Badge';
import { LocalizationProvider } from '@mui/x-date-pickers';
import { AdapterDayjs } from '@mui/x-date-pickers/AdapterDayjs'
import { PickersDay } from '@mui/x-date-pickers/PickersDay';
import { DateCalendar } from '@mui/x-date-pickers/DateCalendar';
import { DayCalendarSkeleton } from '@mui/x-date-pickers/DayCalendarSkeleton';
import { Tooltip } from '@mui/material';
import { styled } from '@mui/material/styles';
import Dialog from '@mui/material/Dialog';
import DialogTitle from '@mui/material/DialogTitle';
import DialogContent from '@mui/material/DialogContent';
import IconButton from '@mui/material/IconButton';
import CloseIcon from '@mui/icons-material/Close';
import { useSelector } from 'react-redux';
import CalenderServices from '@/Services/CalenderServices';
import HorizontalRuleIcon from '@mui/icons-material/HorizontalRule';
import "./homepage.css"
// dayjs.locale('en');
const BootstrapDialog = styled(Dialog)(({ theme }) => ({
  '& .MuiDialogContent-root': {
    padding: theme.spacing(2),
  },
  '& .MuiDialogActions-root': {
    padding: theme.spacing(1),
  },
}));

function ServerDay({ highlightedDays = [], day, outsideCurrentMonth, handleClickOpen, ...other }) {
  const language = useSelector((state) => state.language);
  const localStorageLanguage = typeof localStorage !== 'undefined' ? localStorage.getItem('language') : null;
  const isSameDayAndMonth = (d1, d2) => d1.date() === d2.date() && d1.month() === d2.month();
  const dayEvents = highlightedDays.filter((highlightedDay) => isSameDayAndMonth(day, highlightedDay.date));
  const isSelected = !outsideCurrentMonth && dayEvents.length > 0;
  return (
    <Tooltip
      title={isSelected ? (
        <div>
          {dayEvents.map((highlightedDay, index) => (
            <div key={index} className='border-bottom cursor fw-bold p-1' onClick={() => handleClickOpen(highlightedDay.event)}>
              {(!language.loading && language.language === "ENGLISH") || (localStorageLanguage === "ENGLISH") ? highlightedDay.event.Title_E : highlightedDay.event.Title_H}
            </div>
          ))}
        </div>
      ) : ''}
    >
      <Badge
        key={day.toString()}
        // overlap="rectangular"
        badgeContent={isSelected ? <HorizontalRuleIcon color={'success'} sx={{ width: "70px", marginTop: "80px", marginRight: "40px" }} /> : undefined}
      >
        <PickersDay {...other} outsideCurrentMonth={outsideCurrentMonth} day={day} />
      </Badge>
    </Tooltip>
  );
}

export default function DateCalendarServerRequest() {
  const language = useSelector((state) => state.language);
  const localStorageLanguage = typeof localStorage !== 'undefined' ? localStorage.getItem('language') : null;
  const requestAbortController = useRef(null);
  const [isLoading, setIsLoading] = useState(false);
  const [highlightedDays, setHighlightedDays] = useState([]);
  const [data, setData] = useState({});
  const [open, setOpen] = useState(false);
  const [HindiMonths, setHindiMonths] = useState('hi');

  const initialValue = dayjs(new Date());

  const handleClickOpen = (event) => {
    setData(event);
    setOpen(true);
  };

  const handleClose = () => {
    setOpen(false);
  };

  const fetchHighlightedDays = (startDate, endDate) => {
    const controller = new AbortController();
    CalenderServices.getforuser({ startdate: startDate, enddate: endDate }, { signal: controller.signal })
      .then(({ data }) => {
        if (data.data) {
          const daysToHighlight = data.data.map(event => ({
            date: dayjs(event.EventDate), // Preserve the original date
            event,
          }));
          setHighlightedDays(daysToHighlight);
          setIsLoading(false);
        }
      })
      .catch((error) => {
        console.error(error);
      });

    requestAbortController.current = controller;
  };

  useEffect(() => {
    if ((!language.loading && language.language === "ENGLISH") || (localStorageLanguage === "ENGLISH")) {
      setHindiMonths('en')
    } else {
      setHindiMonths('hi')
    }
  }, [language]);

  useEffect(() => {
    const startOfMonth = initialValue.startOf('month').format('MM-DD');
    const endOfMonth = initialValue.endOf('month').format('MM-DD');
    fetchHighlightedDays(startOfMonth, endOfMonth);
    return () => requestAbortController.current?.abort();
  }, []);

  const handleMonthChange = (date) => {
    if (requestAbortController.current) {
      requestAbortController.current.abort();
    }

    setIsLoading(true);
    setHighlightedDays([]);
    const startOfMonth = date.startOf('month').format('MM-DD');
    const endOfMonth = date.endOf('month').format('MM-DD');
    fetchHighlightedDays(startOfMonth, endOfMonth);
  };

  return (
    <LocalizationProvider dateAdapter={AdapterDayjs} adapterLocale={`${HindiMonths}`}>
      <DateCalendar
        // value={initialValue}
        defaultValue={initialValue}
        onMonthChange={handleMonthChange}
        renderLoading={() => <DayCalendarSkeleton />}
        slots={{
          day: (dayProps) => <ServerDay {...dayProps} highlightedDays={highlightedDays} handleClickOpen={handleClickOpen} />,
        }}
      />

      <BootstrapDialog
        fullWidth
        maxWidth="md"
        open={open}
      >
        <DialogTitle id="customized-dialog-title">
          {(!language.loading && language.language === "ENGLISH") || (localStorageLanguage === "ENGLISH") ? data.Title_E : data.Title_H}
        </DialogTitle>

        <IconButton
          aria-label="close"
          onClick={handleClose}
          sx={{
            position: 'absolute',
            right: 8,
            top: 8,
            color: (theme) => theme.palette.grey[500],
          }}
        >
          <CloseIcon />
        </IconButton>

        <DialogContent dividers>
          {(!language.loading && language.language === "ENGLISH") || (localStorageLanguage === "ENGLISH") ? (
            <div dangerouslySetInnerHTML={{ __html: data.Texts_E }} />
          ) : (
            <div dangerouslySetInnerHTML={{ __html: data.Texts_H }} />
          )}
        </DialogContent>
      </BootstrapDialog>
    </LocalizationProvider>
  );
}


