import React, { useEffect, useState } from "react";
import Dialog from "@mui/material/Dialog";
import DialogContent from "@mui/material/DialogContent";
import Button from "@mui/material/Button";
import { Checkbox, FormControlLabel, TextField } from "@mui/material";
import Switch from "@mui/material/Switch";
import SubjectTreeServices from "@/Services/SubjectTreeServices";
import { toast } from "react-toastify";

const AddEditNodeModal = ({
    open,
    nodeId,
    onclose,
    addEditNum,
    dataForEdit,
    newNodeData,
    modelName
}) => {
    console.log(dataForEdit)
    const [addNodeValues, setAddNodeValues] = useState({
        NodeName_E: "",
        NodeName_H: "",
        NodeUrl: "",
        NodeEnable: false,
        NodeType: "",
        isPractice: false,
        isQuiz: false,
        isCantents: false
    });
    const [dialogError, setdialogError] = useState("");

    const handleClose = () => {
        setdialogError("");
        setAddNodeValues({
            NodeName_E: "",
            NodeName_H: "",
            NodeUrl: "",
            NodeEnable: false,
            NodeType: "",
            isPractice: false,
            isQuiz: false,
            isCantents: false
        });
        onclose(false);
    };

    const handleChangenodeEnable = (event) => {
        setAddNodeValues({
            ...addNodeValues,
            ["NodeEnable"]: event.target.checked,
        });
    };

    const addNodeValueHandeler = (e) => {
        const { name, value } = e.target;
        setAddNodeValues({
            ...addNodeValues,
            [name]: value,
        });
    };

    const handleFileChange = (event) => {
        const file = event.target.files[0];
        setAddNodeValues((prevValues) => ({
            ...prevValues,
            Subject_img: file,
        }));
    };
    const addisCantentsHandler = (e) => {
        const isChecked = e.target.checked;
        setAddNodeValues((prevValues) => ({
            ...prevValues,
            isCantents: isChecked
        }));
    };

    const addisPracticeHandler = (e) => {
        const isChecked = e.target.checked;
        setAddNodeValues((prevValues) => ({
            ...prevValues,
            isPractice: isChecked
        }));
    };
    const addisQuizHandler = (e) => {
        const isChecked = e.target.checked;
        setAddNodeValues((prevValues) => ({
            ...prevValues,
            isQuiz: isChecked
        }));
    };

    const AddNodeSubmit = (add) => {
        const formData = new FormData();
        formData.append("NodeName_E", addNodeValues.NodeName_E);
        formData.append("NodeName_H", addNodeValues.NodeName_H);
        formData.append("NodeUrl", addNodeValues.NodeUrl);
        formData.append("NodeEnable", addNodeValues.NodeEnable);
        formData.append("NodeType", addNodeValues.NodeType);
        formData.append("Subject_img", addNodeValues.Subject_img);
        formData.append("isPractice", addNodeValues.isPractice);
        formData.append("isQuiz", addNodeValues.isQuiz);
        formData.append("isCantents", addNodeValues.isCantents);
        
        SubjectTreeServices.addNode(nodeId, formData)
            .then(({ data }) => {
                if (data?.message?.length > 0) {
                    setAddNodeValues({
                        NodeName_E: "",
                        NodeName_H: "",
                        NodeUrl: "",
                        NodeEnable: false,
                        NodeType: "",
                        isPractice: false,
                        isQuiz: false,
                        isCantents: false
                    });
                    newNodeData(data?.newNode, add);
                    setdialogError("");
                    onclose(false);
                    toast.success(data?.message);
                }
            })
            .catch((res) => {
                // setdialogError(res?.response?.data?.error);
                console.log(res);
            });
    };

    useEffect(() => {
        if (Object.keys(dataForEdit)?.length > 0) { 
            setAddNodeValues({
                NodeName_H: dataForEdit?.NodeName_H,
                NodeName_E: dataForEdit?.NodeName_E,
                NodeUrl: dataForEdit?.NodeUrl,
                NodeEnable: dataForEdit?.NodeEnable,
                NodeType: "",
                isPractice: dataForEdit.isPractice,
                isQuiz: dataForEdit.isQuiz,
                isCantents: dataForEdit.isCantents
                
            });
        }
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [open]);

    const editNodeSubmit = (edit) => {
        const formData = new FormData();
        formData.append("NodeName_E", addNodeValues.NodeName_E);
        formData.append("NodeName_H", addNodeValues.NodeName_H);
        formData.append("NodeEnable", addNodeValues.NodeEnable);
        formData.append("NodeType", addNodeValues.NodeType);
        formData.append("Subject_img", addNodeValues.Subject_img);
        formData.append("isCantents", addNodeValues.isCantents);
        formData.append("isPractice", addNodeValues.isPractice);
        formData.append("isQuiz", addNodeValues.isQuiz);


        SubjectTreeServices.editNode(nodeId, formData)
            .then(({ data }) => {
                newNodeData(data?.newNode, edit);
                onclose(false);
            })
            .catch((res) => {
                console.log(res, "no error 🥰");
            });
    };

    return (
        <div>
            <Dialog
                open={open}
                aria-labelledby="alert-dialog-title"
                aria-describedby="alert-dialog-description"
            >
                <DialogContent className="dialog_container">
                    <div className="text-center">
                   
                        <h3 className="dialog_title">{modelName}</h3>
                    
                        {/* <h3 className="dialog_title">Add Subject</h3> */}
                        <div className="row">
                            <div className="col-md-12">
                                {" "}
                                <TextField
                                    fullWidth
                                    size="small"
                                    className="mt-3 mt-md-4"
                                    id="outlined-basic"
                                    label="Title Name English *"
                                    variant="outlined"
                                    name="NodeName_E"
                                    value={addNodeValues.NodeName_E}
                                    onChange={addNodeValueHandeler}
                                    multiline
                                    rows={3}
                                />
                            </div>
                            <div className="col-md-12">
                                {" "}
                                <TextField
                                    fullWidth
                                    size="small"
                                    className="mt-3 mt-md-4"
                                    id="outlined-basic"
                                    label="Title Name Hindi *"
                                    variant="outlined"
                                    name="NodeName_H"
                                    value={addNodeValues.NodeName_H}
                                    onChange={addNodeValueHandeler}
                                    multiline
                                    rows={3}
                                />
                            </div>
                            {(dataForEdit?.ParentId == 0 || nodeId == 0) && (
                                <div className="col-md-12">
                                    <TextField
                                        className="mt-3 mt-md-4"
                                        fullWidth
                                        size="small"
                                        // label="Subject image"
                                        accept="image/*"
                                        id="upload-file"
                                        type="file"
                                        onChange={handleFileChange}
                                    />
                                </div>
                            )}
                            {/* <div className='col-md-6'> <TextField fullWidth size='small' className='mt-3 mt-md-4' id="outlined-basic" label="NodeUrl" variant="outlined" name='NodeUrl' value={addNodeValues.NodeUrl} onChange={addNodeValueHandeler} /></div> */}
                            <div className="col-md-3 mt-4">
                                <FormControlLabel
                                    value="start"
                                    control={
                                        <Checkbox
                                            checked={addNodeValues?.isCantents}
                                            onChange={addisCantentsHandler}
                                        />
                                    }
                                    label="Content"
                                    labelPlacement="isContent"
                                />
                            </div>
                            <div className="col-md-3 mt-4">
                                <FormControlLabel
                                    value="start"
                                    control={
                                        <Checkbox
                                            checked={addNodeValues?.isPractice}
                                            onChange={addisPracticeHandler}
                                        />
                                    }
                                    label="Practice"
                                    labelPlacement="Practice"
                                />
                            </div>
                            <div className="col-md-3 mt-4">
                                <FormControlLabel
                                    value="start"
                                    control={
                                        <Checkbox
                                            checked={addNodeValues?.isQuiz}
                                            onChange={addisQuizHandler}
                                        />
                                    }
                                    label="Quize"
                                    labelPlacement="Quize"
                                />
                            </div>
                            <div
                                className="col-md-3 text-start mt-4 d-flex"
                                style={{ alignItems: "center" }}
                            >
                                {" "}
                                <h6>Show/Hide </h6>
                                <Switch
                                    onChange={handleChangenodeEnable}
                                    name="NodeEnable"
                                    checked={addNodeValues.NodeEnable}
                                    inputProps={{ "aria-label": "controlled" }}
                                />
                            </div>
                        </div>
                        <div className="d-flex justify-content-between mt-5">
                            <h6 className="text-danger">{dialogError}</h6>
                            <div>
                                <Button
                                    variant="contained"
                                    className="cancel_button mx-3"
                                    size="small"
                                    onClick={handleClose}
                                >
                                    cancel
                                </Button>
                                {addEditNum === 0 && (
                                    <Button
                                        variant="contained"
                                        className="submit_button"
                                        size="small"
                                        onClick={() => AddNodeSubmit(true)}
                                    >
                                        submit
                                    </Button>
                                )}
                                {addEditNum === 1 && (
                                    <Button
                                        variant="contained"
                                        className="submit_button"
                                        size="small"
                                        onClick={() => editNodeSubmit(false)}
                                    >
                                        edit
                                    </Button>
                                )}
                            </div>
                        </div>
                    </div>
                </DialogContent>
            </Dialog>
        </div>
    );
};

export default AddEditNodeModal;